/* SwingML
 * Copyright (C) 2002 Robert Morris.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Robert Morris <robertj@morris.net>
 *
 */
package org.swingml;

import javax.swing.LookAndFeel;

/**
 * This interface provides a means for extending the default
 * L&F offerings provided by the renderer (Metal, Motif, and Windows on
 * Windows platforms).  
 * 
 * @author <a href="mailto:robertj@morris.net">Robert J. Morris</a>
 */
public interface ExternalLookAndFeel {
    /**
     * This method returns a LookAndFeel instance to be used by the 
     * renderer.  In order to use this interface in the renderer, 
     * set the LAF attribute of the &lt;PANEL&gt; tag to &quot;External&quot;
     * then supply the EXT-LAF attribute to the &lt;PANEL&gt; tag with 
     * the fully qualified class definition of the ExternalLookAndFeel 
     * implementer.
     *
     * @return LookAndFeel - A reference to a valid instance of LookAndFeel.
     */
    public LookAndFeel getLookAndFeel();
}