/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

/*Encapsulates common attributes for SwingML models*/

package org.swingml;

import java.util.List;
import java.util.Vector;

public class SwingMLModel {
    private String name = null;
    private String orientation = null;
    private String text = null;
    private String tooltip = null;
    private String icon = null;
    private List listeners = null;
    private String layout = null;
    private List children = null;
    private SwingMLModel parent = null;

    public void setParent(SwingMLModel aParent) {
        this.parent = aParent;
    }

    public SwingMLModel getParent() {
        return this.parent;
    }

    public void addChild(Object aChild) {
        this.getChildren().add(aChild);
    }

    public List getChildren() {
        if (this.children == null) {
            this.children = new Vector();
        }
        return this.children;
    }

    public String getLayout() {
        return this.layout;
    }

    public void setLayout(String aLayout) {
        this.layout = aLayout;
    }

    public String getName() {
        return this.name;
    }

    public String getOrientation() {
        return this.orientation;
    }

    public void setName(String aName) {
        this.name = aName;
    }

    public void setOrientation(String anOrientation) {
        this.orientation = anOrientation;
    }

    public String getText() {
        return this.text;
    }

    public void setText(String aText) {
        this.text = aText;
    }

    public void addListener(Object aListener) {
        this.getListeners().add(aListener);
    }

    public List getListeners() {
        if (this.listeners == null) {
            this.listeners = new Vector();
        }
        return listeners;
    }

    public String getTooltip() {
        return this.tooltip;
    }

    public void setTooltip(String aTooltip) {
        this.tooltip = aTooltip;
    }

    public String getIcon() {
        return this.icon;
    }

    public void setIcon(String anIcon) {
        this.icon = anIcon;
    }

    public void validate() {
    }
}