/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml;

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Toolkit;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import java.io.BufferedReader;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLEncoder;

import javax.swing.JApplet;
import javax.swing.JFrame;
import javax.swing.JPanel;

import org.swingml.event.ExternalEventManager;
import org.swingml.view.RendererUtil;
import org.swingml.xml.MapperUtil;
import org.w3c.dom.Node;


/**
 * This class represents the heart of the SwingML system.  Use this class as either 
 * an application or applet.  The two most significant methods are the submit() and 
 * render() methods.
 * 
 * @author <a href="mailto:ecuellar@crosslogic.com">Ezequiel Cuellar</a>
 * @author <a href="mailto:robertj@morris.net">Robert J. Morris</a>
 */
public class SwingMLRenderer extends JApplet {

    public static SwingMLRenderer renderer = null;

    /**
     * Called when a SwingMLRenderer instance is displayed or run as an applet.
     */
    public void init() {
        renderer = this;
        URLHandler.codebase = super.getCodeBase();
        String theSpec = this.getSpec(getParameter("SPEC"));
        this.render(theSpec, this.getContentPane());
    }

    public void destroy() {
        ExternalEventManager.flush(this);
    }

    /**
     * When this class is used as the entry point for an application.  This method 
     * expects that the 0th element in the args[] parameter contains the URL
     * of the SwingML document to render.
     */
    public static void main(String args[]) {
        if (args.length != 0) {
            JFrame theFrame = new JFrame();
            theFrame.addWindowListener(new WindowListener() {
                public void windowOpened(WindowEvent e) {
                }

                public void windowClosing(WindowEvent e) {
                    System.exit(0);
                    ExternalEventManager.flush();
                }

                public void windowClosed(WindowEvent e) {
                }

                public void windowIconified(WindowEvent e) {
                }

                public void windowDeiconified(WindowEvent e) {
                }

                public void windowActivated(WindowEvent e) {
                }

                public void windowDeactivated(WindowEvent e) {
                }
            });

            try {
                int theWidth = Integer.parseInt(args[1]);
                int theHeight = Integer.parseInt(args[2]);
                theFrame.setSize(theWidth, theHeight);
            } catch (Exception e) {
                theFrame.setSize(550, 500);
            }

            Dimension theScreenSize = Toolkit.getDefaultToolkit().getScreenSize();
            Dimension theFrameSize = theFrame.getSize();
            int theHorizontalPosition = (int) (theScreenSize.getWidth() - theFrameSize.getWidth()) / 2;
            int theVerticalPosition = (int) (theScreenSize.getHeight() - theFrameSize.getHeight()) / 2;
            theFrame.setLocation(theHorizontalPosition, theVerticalPosition);

            SwingMLRenderer theRenderer = new SwingMLRenderer();
            renderer = theRenderer;
            URLHandler.setURLCodeBase(System.getProperty("user.dir"));
            theFrame.getContentPane().add(theRenderer);
            String spec = theRenderer.getSpec(args[0]);
            theRenderer.render(spec, theRenderer.getContentPane());
            theFrame.setVisible(true);
        } else {
            System.out.println("Specification URL missing.");
        }
    }

    /**
     * This method returns a string containing the document specified by 
     * the url arugment.
     * 
     * @param	url	A String representing the fully qualified URL of the 
     * document to retrieve.
     * 
     * @return	A String containing the document referenced by the url
     * parameter.  If an error occurred a zero-length string ("") is returned.
     */
    public String getSpec(String aUrl) {
        StringBuffer theValueBuffer = new StringBuffer();
        try {
            URL theSource = URLHandler.handle(aUrl);
            URLConnection theConnection = theSource.openConnection();
            theConnection.setUseCaches(false);
            BufferedReader theBufferedReader = new BufferedReader(new InputStreamReader(theConnection.getInputStream()));
            String theLine = null;
            while ((theLine = theBufferedReader.readLine()) != null) {
                theValueBuffer.append(theLine);
                theValueBuffer.append('\n');
            }
            theBufferedReader.close();
        } catch (MalformedURLException e) {
            System.out.println(e);
        } catch (IOException e) {
            System.out.println(e);
        }
        return theValueBuffer.toString();
    }

    /**
     * Uses the parent parameter as a starting point for building the parameters 
     * to use during a submit() operation.
     * 
     * @param	parent	A reference to the Container to use as the root during 
     * the construction of the document's parameters.
     */
    public String buildHttpRequest(Container aContainer) {
        StringBuffer theFormParameters = new StringBuffer();
        this.processFormParameters(aContainer, theFormParameters);
        if (theFormParameters.length() != 0) {
            theFormParameters.deleteCharAt(theFormParameters.length() - 1);
        }
        return theFormParameters.toString();
    }

    public void submit(String anAddress, Container aContainer) {
        try {
            ExternalEventManager.flush(this);

            // Creates the HTTP request.
            String theHttpRequest = this.buildHttpRequest(aContainer);

            // Performs Http Request.
            URL theUrl = URLHandler.handle(anAddress);
            URLConnection theUrlConnection = (URLConnection) theUrl.openConnection();
            theUrlConnection.setUseCaches(false);
            theUrlConnection.setDoOutput(true);

            ByteArrayOutputStream theByteStream = new ByteArrayOutputStream(512);
            PrintWriter theOutput = new PrintWriter(theByteStream, true);
            theOutput.print(theHttpRequest);
            theOutput.flush();

            String theLengthString = String.valueOf(theByteStream.size());
            theUrlConnection.setRequestProperty("Content-Length", theLengthString);
            theUrlConnection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
            theByteStream.writeTo(theUrlConnection.getOutputStream());

            // Receives Http Response.
            InputStreamReader theInputStreamReader = new InputStreamReader(theUrlConnection.getInputStream());
            BufferedReader theBufferedReader = new BufferedReader(theInputStreamReader);
            StringBuffer theHttpResponse = new StringBuffer();
            String theLine = null;
            while ((theLine = theBufferedReader.readLine()) != null) {
                theHttpResponse.append(theLine);
                theHttpResponse.append('\n');
            }
            String theSwingMLSpec = theHttpResponse.toString();
            if (aContainer.isDisplayable()) {
                aContainer.removeAll();
                aContainer.validate();
                this.render(theSwingMLSpec, aContainer);
            }
            theBufferedReader.close();
            theByteStream.close();
            theOutput.close();
        } catch (MalformedURLException e) {
            System.out.println(e);
        } catch (IOException e) {
            System.out.println(e);
        }
    }

    public void processFormParameters(Container aContainer, StringBuffer aFormParameters) {
        try {
            Component[] aComponents = aContainer.getComponents();
            Component theComponent = null;
            XMLTranslatable theXMLTranslatableComponent = null;
            for (int i = 0; i < aComponents.length; i++) {
                theComponent = aComponents[i];
                if (theComponent instanceof XMLTranslatable) {
                    theXMLTranslatableComponent = (XMLTranslatable) theComponent;
                    aFormParameters.append(theComponent.getName() + "=");
                    aFormParameters.append(URLEncoder.encode(theXMLTranslatableComponent.getXMLValue(), "UTF-8") + "&");
                }
                this.processFormParameters((Container) theComponent, aFormParameters);
            }
        } catch (UnsupportedEncodingException e) {
            System.out.println(e);
        }
    }

    public void render(String aSpec, Container aContainer) {
        SwingMLModel theForm = new SwingMLModel();
        MapperUtil theMapperUtil = new MapperUtil();
        Node theNode = (Node) theMapperUtil.parse(aSpec);
        theMapperUtil.iterate(theNode, theForm);
        RendererUtil theRendererUtil = new RendererUtil();
        theRendererUtil.iterate(theForm, aContainer);
        JPanel theContainer = (JPanel) aContainer;
        theContainer.updateUI();
    }

    public static SwingMLRenderer getRenderer() {
        return renderer;
    }
}