/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.component;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.FlowLayout;
import java.awt.GridLayout;

import javax.swing.AbstractButton;
import javax.swing.ButtonGroup;
import javax.swing.JPanel;
import javax.swing.border.BevelBorder;
import javax.swing.border.EtchedBorder;

import org.swingml.Constants;
import org.swingml.model.ButtonGroupModel;


public class ButtonGroupComponent extends JPanel {
    
    ButtonGroup buttonGroup = new ButtonGroup();

    public ButtonGroupComponent(ButtonGroupModel aModel) {
        String theName = aModel.getName();
        String theBorder = aModel.getBorder();
        String theLayout = aModel.getLayout();
        int theBevelType = aModel.getBevelType();
        int theRows = aModel.getRows();
        int theCols = aModel.getCols();
        super.setName(theName);
        if (theBorder.equalsIgnoreCase(Constants.ETCHEDBORDER)) {
            super.setBorder(new EtchedBorder());
        }
        if (theBorder.equalsIgnoreCase(Constants.BEVELBORDER)) {
            super.setBorder(new BevelBorder(theBevelType));
        }
        if (theLayout.equalsIgnoreCase(Constants.FLOWLAYOUT)) {
            super.setLayout(new FlowLayout());
        }
        if (theLayout.equalsIgnoreCase(Constants.GRIDLAYOUT)) {
            super.setLayout(new GridLayout(theRows, theCols));
        }
        if (theLayout.equalsIgnoreCase(Constants.BORDERLAYOUT)) {
            super.setLayout(new BorderLayout());
        }
        if (theLayout.equalsIgnoreCase(Constants.NONE)) {
            super.setLayout(null);
        }
    }

    public void add(Component aButton, Object orientation) {
        super.add(aButton, orientation);
        buttonGroup.add((AbstractButton) aButton);
    }
    
    public Component add(Component aButton) {
        super.add(aButton);
        buttonGroup.add((AbstractButton) aButton);
        return aButton;
    }    
}