/* SwingML
 * Copyright (C) 2002 Robert Morris.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Robert Morris <robertj@morris.net>
 *
 */

package org.swingml.component;

import java.awt.Component;
import java.awt.Container;

import org.swingml.model.GridBagRowModel;


/**
 * This class simply contains necessary GridBagLayout formatting instructions 
 * as well as a list of references to 0 or more GridBagCellComponent instances.
 * As the components contained within this hierarchy are added to the enclosing
 * GridBagPanelComponent instance, the formatting instructions are hierarchically
 * applied to the layout.
 * 
 * @see org.swingml.component.GridBagPanelComponent
 * @see org.swingml.component.GridBagCellComponent
 */
public class GridBagRowComponent extends Container {

    private GridBagPanelComponent m_parentPanel = null;
    private GridBagRowModel m_model = null;
    private int m_cols = 0;

    /**
     * This method sets the parent panel property to the one 
     * specified by the parentPanel parameter.  This allows the 
     * current GridBagRowComponent instance to add forward this
     * reference to contained instances of the GridBagCellComponent class.
     * 
     * @param	parentPanel	A valid reference to a GridBagPanelComponent instance.
     * 
     * @see org.swingml.component.GridBagPanelComponent
     */
    public void setParentPanel(GridBagPanelComponent aParentPanel) {
        this.m_parentPanel = aParentPanel;
    }

    /**
     * This add() method override, assumes that the class of the 
     * supplied component argument will resolve to an instance
     * of the GridBagCellComponent class.  This way the addition
     * of components to the enclosing GridBagPanelComponent instance
     * are laid out properly.  A reference to any other class will simply
     * return the referenced component, but not add it to the enclosing
     * GridBagPanelComponent instance.
     * 
     * @param	component	A valid reference to an instance of the GridBagCellComponent class.
     * 
     * @see org.swingml.component.GridBagPanelComponent
     * @see org.swingml.component.GridBagCellComponent
     */
    public Component add(Component aComponent) {
        if (aComponent instanceof GridBagCellComponent) {
            GridBagCellComponent theComponent = (GridBagCellComponent) aComponent;
            theComponent.setParentPanel(this.m_parentPanel);
            theComponent.setColumn(this.m_cols);
            this.m_cols++;
        }
        return aComponent;
    }

    /**
     * Creates a GridBagRowComponent instance.
     */
    public GridBagRowComponent(GridBagRowModel aModel) {
        this.m_model = aModel;
    }
}