/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.component;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.JCheckBox;

import org.swingml.Constants;
import org.swingml.XMLTranslatable;
import org.swingml.event.EventHandler;
import org.swingml.model.JCheckBoxModel;


public class JCheckBoxComponent extends JCheckBox implements XMLTranslatable, ItemListener {

    private EventHandler eventHandler = EventHandler.getInstance();
    private JCheckBoxModel model = null;

    public JCheckBoxComponent(JCheckBoxModel aModel) {
        model = aModel;
        super.setName(model.getName());
        super.setText(model.getText());
        super.setToolTipText(model.getTooltip());
        super.setSelected(model.isChecked());
        super.addItemListener(this);
        super.setEnabled(aModel.isEnabled());
    }

    public void itemStateChanged(ItemEvent aEvt) {
        if (aEvt.getStateChange() == ItemEvent.SELECTED) {
            this.eventHandler.handleEvent(this.model, Constants.ITEM_STATE_CHANGED_SELECTED, this);
        } else if (aEvt.getStateChange() == ItemEvent.DESELECTED) {
            this.eventHandler.handleEvent(this.model, Constants.ITEM_STATE_CHANGED_DESELECTED, this);
        }
    }

    public String getXMLValue() {
        return Boolean.toString(super.isSelected());
    }
}