/* SwingML
 * Copyright (C) 2003 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.component;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;

import javax.swing.JEditorPane;
import javax.swing.event.HyperlinkEvent;
import javax.swing.event.HyperlinkListener;
import javax.swing.text.html.HTMLDocument;
import javax.swing.text.html.HTMLFrameHyperlinkEvent;

import org.swingml.XMLTranslatable;
import org.swingml.model.JEditorPaneModel;


public class JEditorPaneComponent extends JEditorPane implements XMLTranslatable, HyperlinkListener {

    public JEditorPaneComponent(JEditorPaneModel aModel) {
        try {
            JEditorPaneModel theModel = (JEditorPaneModel) aModel;
            super.setEditable(false);
            super.setName(theModel.getName());
            super.setPage(new URL(theModel.getPage()));
            super.setToolTipText(theModel.getTooltip());
            super.setEditable(theModel.isEditable());
            super.addHyperlinkListener(this);
        } catch (MalformedURLException e) {
        } catch (IOException e) {
        }
    }

    public void hyperlinkUpdate(HyperlinkEvent anEvt) {
        if (anEvt.getEventType() == HyperlinkEvent.EventType.ACTIVATED) {
            if (anEvt instanceof HTMLFrameHyperlinkEvent) {
                HTMLDocument theDocument = (HTMLDocument) getDocument();
                theDocument.processHTMLFrameHyperlinkEvent((HTMLFrameHyperlinkEvent) anEvt);
            } else {
                try {
                    setPage(anEvt.getURL());
                } catch (IOException e) {
                    System.out.println(e);
                }
            }
        }
    }

    public String getXMLValue() {
        return super.getText();
    }
}