/* SwingML
 * Copyright (C) 2002 Marcelo W. Lopez Cremona.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 * 	   Marcelo W. Lopez Cremona <marcelo_java@argentina.com>   
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.component;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.URL;

import javax.swing.ImageIcon;
import javax.swing.JMenu;
import javax.swing.JMenuItem;

import org.swingml.Constants;
import org.swingml.event.EventHandler;
import org.swingml.model.JMenuItemModel;


public class JMenuItemComponent extends JMenuItem implements ActionListener {

    private EventHandler eventHandler = EventHandler.getInstance();
    private JMenuItemModel model = null;
    private JMenu menuParent = null;

    public JMenuItemComponent(JMenuItemModel aModel) {
        try {
            this.model = aModel;
            super.setText(model.getText());
            super.setName(model.getName());
            super.setMnemonic(model.getMnemonic());
            super.setToolTipText(model.getTooltip());
            super.addActionListener(this);
            if (model.getIcon() != null) {
                super.setIcon(new ImageIcon(new URL(model.getIcon())));
            }
        } catch (Exception e) {
        }
    }

    public void actionPerformed(ActionEvent aEvt) {
        this.eventHandler.handleEvent(this.model, Constants.ACTION_PERFORMED, this.menuParent);
    }

    public void setMenuParent(JMenu aParent) {
        this.menuParent = aParent;
    }
}