/* SwingML
 * Copyright (C) 2002 Hamdi Mohs Yusof.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Hamdi Mohs Yusof <hamdi@medical-online.net>         
 *
 */

package org.swingml.component;

import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;

import javax.swing.JPasswordField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

import org.swingml.Constants;
import org.swingml.XMLTranslatable;
import org.swingml.event.EventHandler;
import org.swingml.model.JPasswordModel;


public class JPasswordComponent extends JPasswordField implements XMLTranslatable, DocumentListener, FocusListener {
    private JPasswordModel model = null;
    private EventHandler eventHandler = EventHandler.getInstance();

    public JPasswordComponent(JPasswordModel aModel) {
        this.model = aModel;
        super.setName(aModel.getName());
        super.setText(aModel.getText());
        super.setColumns(Integer.parseInt(aModel.getCols()));
        super.getDocument().addDocumentListener(this);
        super.addFocusListener(this);
        super.setToolTipText(aModel.getTooltip());
    }

    public JPasswordModel getModel() {
        return this.model;
    }

    public void removeUpdate(DocumentEvent aEvt) {
        this.eventHandler.handleEvent(this.getModel(), Constants.REMOVE_UPDATE, this);
    }

    public void insertUpdate(DocumentEvent aEvt) {
        this.eventHandler.handleEvent(this.getModel(), Constants.INSERT_UPDATE, this);
    }

    public void changedUpdate(DocumentEvent aEvt) {
        this.eventHandler.handleEvent(this.getModel(), Constants.CHANGED_UPDATE, this);
    }

    public void focusGained(FocusEvent aEvt) {
        this.eventHandler.handleEvent(this.getModel(), Constants.FOCUS_GAINED, this);
    }

    public void focusLost(FocusEvent aEvt) {
        this.eventHandler.handleEvent(this.getModel(), Constants.FOCUS_LOST, this);
    }

    public String getXMLValue() {
        String theValue = new String(super.getPassword());
        return theValue;
    }
}