/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */
package org.swingml.component;

import javax.swing.JSlider;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import org.swingml.Constants;
import org.swingml.event.EventHandler;
import org.swingml.model.JSliderModel;


public class JSliderComponent extends JSlider implements ChangeListener {

    private EventHandler eventHandler = EventHandler.getInstance();
    private JSliderModel model = null;

    public JSliderComponent(JSliderModel aModel) {
        this.model = aModel;
        super.setName(aModel.getName());
        super.setEnabled(aModel.isEnabled());
        super.setToolTipText(aModel.getTooltip());
        super.setMinimum(aModel.getMinimum());
        super.setMaximum(aModel.getMaximum());
        super.setValue(aModel.getValue());
        super.setOrientation(aModel.getType());
        super.setPaintLabels(true);
        super.setPaintTicks(true);
        super.setMajorTickSpacing(aModel.getMaximum());
        super.setMinorTickSpacing(aModel.getMinimum() + 1);
        addChangeListener(this);
    }

    public void stateChanged(ChangeEvent aEvt) {
        this.eventHandler.handleEvent(this.model, Constants.CHANGE_LISTENER, this);
    }
}