/* SwingML
 * Copyright (C) 2002 Robert Morris.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Robert Morris <robertj@morris.net>
 *
 */

package org.swingml.component;

import java.awt.Component;

import javax.swing.JSplitPane;

import org.swingml.Constants;
import org.swingml.model.JSplitPaneModel;


public class JSplitPaneComponent extends JSplitPane {
    private JSplitPaneModel m_model = null;
    private boolean m_isLeft = false;

    /**
     * Performs the necessary checking to make sure that a SwingML component
     * is properly added to the JSplitPane.  Forces Left vs. Right additions.
     * The designation of "left" component and "right" component alternates with
     * each additional add.  Therefore, the first component is the left component,
     * the second component added is the right component.  If a third were added, it
     * it would be the left component, and the fourth would become the right component.
     * 
     * @param	component	The component to add to the JSplitPaneComponent.
     */
    public Component add(Component aComponent) {
        this.m_isLeft = !this.m_isLeft;
        if (this.m_isLeft) {
            super.add(aComponent, JSplitPane.LEFT);
        } else {
            super.add(aComponent, JSplitPane.RIGHT);
        }
        return aComponent;
    }

    /**
     * Class constructor
     * 
     * @param	model	A reference to a valid JSplitPaneModel instance.  This
     * 					reference is used to properly instantiate the JSplitPane 
     *					component with information provided by the JSplitPaneModel 
     * 					instance.
     */
    public JSplitPaneComponent(JSplitPaneModel aModel) {
        super((aModel.getType().equalsIgnoreCase(Constants.SPLIT_HORIZONTAL) ? JSplitPane.HORIZONTAL_SPLIT : JSplitPane.VERTICAL_SPLIT));
        this.m_model = aModel;
        super.setDividerSize(aModel.getSize());
        super.setName(aModel.getName());
        super.setToolTipText(aModel.getTooltip());
        if (aModel.getLocation() instanceof Integer) {
            super.setDividerLocation(((Integer) aModel.getLocation()).intValue());
        } else if (aModel.getLocation() instanceof Double) {
            double theNewLocation = ((Double) aModel.getLocation()).doubleValue();
            if (theNewLocation < 1 || theNewLocation > 100) {
                System.out.println("Syntax Error: LOCATION % for SPLITTER [" + aModel.getName() + "] can only be between 1 and 100");
                // Set a default value of 50%.
                theNewLocation = (double) 0.5;
            } else {
                theNewLocation *= 0.01;
            }
            super.setDividerLocation(theNewLocation);
        }
    }

}