/*
 * SwingML
 * Copyright (C) 2002 Robert J. Morris.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Robert J. Morris <robertj@morris.net>
 * 
 * Oct 8, 2002 10:09:40 PM
 */
package org.swingml.component;

import java.awt.Component;

import javax.swing.JTabbedPane;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import org.swingml.Constants;
import org.swingml.XMLTranslatable;
import org.swingml.event.EventHandler;
import org.swingml.model.JTabbedPaneModel;


/**
 *
 * <p>Supports the XMLTranslatable interface to provide feedback during a POST
 * operation.</p>
 */
public class JTabbedPaneComponent extends JTabbedPane implements XMLTranslatable, ChangeListener {

    private EventHandler eventHandler = EventHandler.getInstance();
    private JTabbedPaneModel m_model = null;
    private int m_current = 0;

    /**
     * Creates an instance of the JTabbedPaneComponent class.
     * 
     * @param	model	A valid instance of a JTabbedPaneModel class.  
     * 					provides the necessary information to intialize
     * 					new instance of the JTabbedPaneComponent class.
     */
    public JTabbedPaneComponent(JTabbedPaneModel aModel) {
        super();
        this.m_model = aModel;
        this.m_current = this.m_model.getCurrent();
        super.setName(this.m_model.getName());
        super.setToolTipText(this.m_model.getTooltip());
        super.addChangeListener(this);
    }

    /**
     * Adds a new tab to the component.  Makes sure that the 
     * current tab specified by the JTabbedPaneModel object used
     * to create this instance is used to set the current
     * tab index when it is available.
     * 
     * @param	tabName		The name of the tab to add.
     * @param	component	The component to add to the tabbed pane.
     */
    public Component add(String aTabName, Component aComponent) {
        Component theRetComp = super.add(aTabName, aComponent);
        if (super.getComponentCount() >= (this.m_current + 1)) {
            super.setSelectedIndex(this.m_current);
        }
        return theRetComp;
    }

    /**
     * @see org.swingml.XMLTranslatable#getXMLValue()
     */
    public String getXMLValue() {
        return Integer.toString(super.getSelectedIndex());
    }

    // ChangeListener Realization
    public void stateChanged(ChangeEvent aEvt) {
        this.eventHandler.handleEvent(this.m_model, Constants.TAB_STATE_CHANGED, this);
    }
}