/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.component;

import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.JTable;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.XMLTranslatable;
import org.swingml.event.EventHandler;
import org.swingml.model.JTableModel;


public class JTableComponent extends JTable implements XMLTranslatable, MouseListener, ListSelectionListener {

    private EventHandler eventHandler = EventHandler.getInstance();
    private StringBuffer xmlValue = null;
    private JTableModel m_tableModel = null;

    public JTableComponent(JTableModel aModel) {
        this.m_tableModel = aModel;
        super.setModel(aModel);
        super.setName(aModel.getName());
        super.setToolTipText(aModel.getTooltip());
        super.addMouseListener(this);
        super.getSelectionModel().setSelectionMode(aModel.getMode());
    }

    public String getXMLValue() {
        Object theModel = super.getModel();
        String thePostStyle = Constants.POST_ALL;
        int thePostColumn = 0;
        if (theModel instanceof JTableModel) {
            JTableModel theTableModel = (JTableModel) theModel;
            thePostStyle = theTableModel.getPostStyle();
            thePostColumn = theTableModel.getPostColumn();
        }
        if (!thePostStyle.equalsIgnoreCase(Constants.POST_ALL)) {
            this.xmlValue = new StringBuffer();
            int theColumns = super.getColumnCount();
            thePostColumn = ((theColumns < thePostColumn || thePostColumn < 0) ? 0 : thePostColumn);

            int[] theRows = super.getSelectedRows();
            if (theRows != null) {
                for (int i = 0; i < theRows.length; i++) {
                    this.xmlValue.append(super.getValueAt(theRows[i], thePostColumn).toString());
                    this.xmlValue.append('|');
                }

                if (this.xmlValue.length() > 0 && this.xmlValue.charAt(this.xmlValue.length() - 1) == '|') {
                    this.xmlValue = this.xmlValue.deleteCharAt(this.xmlValue.length() - 1);
                }
            }
        } else {
            this.xmlValue = new StringBuffer();
            this.xmlValue.append("<TABLE NAME=\"" + super.getName() + "\">\n");
            int theColumns = super.getModel().getColumnCount();
            for (int i = 0; i < theColumns; i++) {
                this.xmlValue.append("<TC TEXT=\"" + super.getModel().getColumnName(i) + "\"/>\n");
            }

            int theRows = super.getModel().getRowCount();
            for (int r = 0; r < theRows; r++) {
                this.xmlValue.append("<TR>\n");
                for (int c = 0; c < theColumns; c++) {
                    if (this.getValueAt(r, c) instanceof String) {
                        this.xmlValue.append("<TD TEXT=\"" + super.getModel().getValueAt(r, c) + "\"/>\n");
                    } else {
                        this.xmlValue.append("<TD VALUE=\"" + super.getModel().getValueAt(r, c) + "\"/>\n");
                    }
                }
                this.xmlValue.append("</TR>\n");
            }
            this.xmlValue.append("</TABLE>\n");
        }
        return this.xmlValue.toString();
    }

    /**
     * @see java.awt.event.MouseListener#mouseClicked(MouseEvent)
     */
    public void mouseClicked(MouseEvent aEvt) {
        final int DOUBLE_CLICK_COUNT = 2;
        final int SINGLE_CLICK_COUNT = 1;
        String theEventType = null;
        switch (aEvt.getClickCount()) {
        case DOUBLE_CLICK_COUNT:
            theEventType = Constants.MOUSE_DOUBLE_CLICKED;
            break;
        case SINGLE_CLICK_COUNT:
            theEventType = Constants.MOUSE_SINGLE_CLICKED;
            break;
        default:
            theEventType = null;
            break;
        }
        if (theEventType != null && theEventType.length() > 0) {
            this.eventHandler.handleEvent((SwingMLModel) super.getModel(), theEventType, this);
        }
    }

    /**
     * @see java.awt.event.MouseListener#mouseEntered(MouseEvent)
     */
    public void mouseEntered(MouseEvent aEvt) {
    }

    /**
     * @see java.awt.event.MouseListener#mouseExited(MouseEvent)
     */
    public void mouseExited(MouseEvent aEvt) {
    }

    /**
     * @see java.awt.event.MouseListener#mousePressed(MouseEvent)
     */
    public void mousePressed(MouseEvent aEvt) {
    }

    /**
     * @see java.awt.event.MouseListener#mouseReleased(MouseEvent)
     */
    public void mouseReleased(MouseEvent aEvt) {
    }

    // ListSelectionListener Realization

    public void valueChanged(ListSelectionEvent aEvt) {
        super.valueChanged(aEvt);
        if (this.m_tableModel != null && this.eventHandler != null) {
            eventHandler.handleEvent(this.m_tableModel, Constants.LIST_VALUE_CHANGED, this);
        }
    }
}