/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.component;

import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;

import javax.swing.JTextArea;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.XMLTranslatable;
import org.swingml.event.EventHandler;
import org.swingml.model.JTextAreaModel;


public class JTextAreaComponent extends JTextArea implements XMLTranslatable, DocumentListener, FocusListener {

    private JTextAreaModel model = null;
    private EventHandler eventHandler = EventHandler.getInstance();

    public JTextAreaComponent(JTextAreaModel aModel) {
        this.model = aModel;
        super.setName(aModel.getName());
        super.setColumns(aModel.getCols());
        super.setRows(aModel.getRows());
        super.setText(aModel.getText().trim());
        super.setToolTipText(aModel.getTooltip());
        super.getDocument().addDocumentListener(this);
        super.addFocusListener(this);
        super.setLineWrap(aModel.getLineWrap());
        if (aModel.getBackground() != null) {
            super.setBackground(aModel.getBackground());
        }
        if (aModel.getForeground() != null) {
            super.setForeground(aModel.getForeground());
        }
    }

    public JTextAreaModel getModel() {
        return model;
    }

    public void removeUpdate(DocumentEvent evt) {
        eventHandler.handleEvent((SwingMLModel) this.getModel(), Constants.REMOVE_UPDATE, this);
    }

    public void insertUpdate(DocumentEvent evt) {
        eventHandler.handleEvent((SwingMLModel) this.getModel(), Constants.INSERT_UPDATE, this);
    }

    public void changedUpdate(DocumentEvent aEvt) {
        this.eventHandler.handleEvent(this.getModel(), Constants.CHANGED_UPDATE, this);
    }

    public void focusGained(FocusEvent aEvt) {
        this.eventHandler.handleEvent(this.getModel(), Constants.FOCUS_GAINED, this);
    }

    public void focusLost(FocusEvent aEvt) {
        this.eventHandler.handleEvent(this.getModel(), Constants.FOCUS_LOST, this);
    }

    public String getXMLValue() {
        return super.getText();
    }
}