/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.component;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;

import javax.swing.tree.DefaultMutableTreeNode;

import org.swingml.model.JTreeModel;
import org.swingml.model.NodeModel;


public class TreeNodeComponent extends DefaultMutableTreeNode implements Transferable {
    private boolean isLeaf = false;
    private String name = null;
    private DataFlavor[] dataFlavors = null;
    public static DataFlavor dataFlavor = new DataFlavor(DataFlavor.javaJVMLocalObjectMimeType + "; class=org.swingml.component.TreeNodeComponent", "TreeNodeComponent");

    public TreeNodeComponent(JTreeModel aModel) {
        Object theChild = null;
        TreeNodeComponent theNode = null;

        this.setName(aModel.getName());
        this.setUserObject(aModel);
        for (int i = 0; i < aModel.getChildren().size(); i++) {
            theChild = aModel.getChildren().get(i);
            if (theChild instanceof JTreeModel) {
                theNode = new TreeNodeComponent((JTreeModel) theChild);
            }
            if (theChild instanceof NodeModel) {
                theNode = new TreeNodeComponent((NodeModel) theChild);
            }
            super.add(theNode);
        }
    }

    public TreeNodeComponent(NodeModel aModel) {
        this.isLeaf = true;
        this.setUserObject(aModel);
    }

    public void setName(String aName) {
        this.name = aName;
    }

    public String getName() {
        return this.name;
    }

    public boolean isLeaf() {
        return this.isLeaf;
    }

    public Object getTransferData(DataFlavor aFlavor) {
        return this;
    }

    public DataFlavor[] getTransferDataFlavors() {
        this.dataFlavors = new DataFlavor[1];
        this.dataFlavors[0] = dataFlavor;
        return dataFlavors;
    }

    public boolean isDataFlavorSupported(DataFlavor aFlavor) {
        boolean theDataFlavorSupported = false;
        if (aFlavor.equals(this.dataFlavors)) {
            theDataFlavorSupported = true;
        }
        return theDataFlavorSupported;
    }
}