/*
 * SwingML Copyright (C) 2002 Ezequiel Cuellar.
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option) any
 * later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * 
 * Authors: 
 * Ezequiel Cuellar <ecuellar@crosslogic.com> 
 * Robert Morris<robertj@morris.net>
 *  
 */

package org.swingml.event;

import java.awt.Component;
import java.awt.Container;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Iterator;
import java.util.StringTokenizer;

import javax.swing.JComponent;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.SwingMLRenderer;
import org.swingml.model.ActionModel;
import org.swingml.model.ExternalActionModel;
import org.swingml.model.ListenerModel;


public class EventHandler {

    public static EventHandler eventHandlerInstance = null;

    public void handleEvent(SwingMLModel anEventOwnerModel, String anEventName, JComponent anEventOwner) {
        //TODO Needs to handle parameters that come from another elements for example: 
        //<ACTION COMPONENT="TextFieldTest" METHOD="setText" VALUE="ComboBoxText.getValue()"/>
        ActionModel theAction = null;
        Component theActionTarget = null;
        ListenerModel theEventListener = this.findEventListener(anEventOwnerModel, anEventName);
        if (theEventListener != null) {
            Iterator theActions = theEventListener.getActions().iterator();
            Object theIteratorObject = null;
            while (theActions.hasNext()) {
                theIteratorObject = theActions.next();
                if (theIteratorObject instanceof ActionModel) {
                    theAction = (ActionModel) theIteratorObject;
                    theActionTarget = this.findActionTarget(anEventOwner.getTopLevelAncestor(), theAction.getComponent());
                    if (theActionTarget != null) {
                        this.processAction(theAction, theActionTarget, anEventOwnerModel.getName(), theEventListener);
                    } else {
                        System.out.println("Syntax error: The component " + theAction.getComponent() + " in the action for the listener " + theEventListener.getEvent() + " in the element " + anEventOwnerModel.getName() + " wasn't found. Verify the value of COMPONENT.");
                    }
                } else if (theIteratorObject instanceof ExternalActionModel) {
                    this.handleExternalEvent((ExternalActionModel) theIteratorObject, anEventOwner, anEventOwnerModel, theEventListener);
                }
            }
        }
    }

    public void handleExternalEvent(ExternalActionModel anExternalAction, JComponent anEventOwner, SwingMLModel anEventOwnerModel, ListenerModel anEventListener) {
        Component theActionTarget = this.findActionTarget(anEventOwner.getTopLevelAncestor(), anExternalAction.getComponent());
        if (theActionTarget != null && anExternalAction.getExternalClass() != null) {
            try {
                SwingMLRenderer theRenderer = new EventHandlerTools().getRenderer(anEventOwner);
                InvokableEvent theInvokableEvent = ExternalEventManager.loadInvokableEvent(theRenderer, anExternalAction.getExternalClass().getName());
                theInvokableEvent.initialize(theActionTarget, anExternalAction.getParams().toArray());
                theInvokableEvent.invoke();
                theInvokableEvent.destroy();
            } catch (Exception e) {
                System.out.println("Syntax Error: Failed to instantiate: [" + anExternalAction.getExternalClass().getName() + "].  Check your CLASSPATH and make sure the referenced class is accessible.");
                e.printStackTrace();
            }
        } else {
            System.out.println("Syntax Error: The component " + anExternalAction.getComponent() + " in the action for the listener " + anEventListener.getEvent() + " in the element " + anEventOwnerModel.getName() + " wasn't found.  Verify the value of COMPONENT.");
        }
    }

    public ListenerModel findEventListener(SwingMLModel anEventOwnerModel, String anEventName) {
        ListenerModel theEventListener = null;
        Iterator theListeners = anEventOwnerModel.getListeners().iterator();
        while (theListeners.hasNext()) {
            theEventListener = (ListenerModel) theListeners.next();
            if (theEventListener.getEvent().equalsIgnoreCase(anEventName)) {
                break;
            }
        }
        return theEventListener;
    }

    public Component findActionTarget(Container aRootContainer, String anActionTargetName) {
        Component theActionTarget = null;
        Component[] theComponents = aRootContainer.getComponents();
        if (aRootContainer.getName() != null && aRootContainer.getName().equals(anActionTargetName)) {
            theActionTarget = aRootContainer;
        } else {
            for (int i = 0; i < theComponents.length; i++) {
                theActionTarget = theComponents[i];
                if (theActionTarget.getName() != null && theActionTarget.getName().equals(anActionTargetName)) {
                    break;
                }
                theActionTarget = this.findActionTarget((Container) theActionTarget, anActionTargetName);
                if (theActionTarget != null) {
                    break;
                }
            }
        }
        return theActionTarget;
    }

    public void processAction(ActionModel anAction, Component anActionTarget, String anEventOwnerName, ListenerModel anEventListener) {
        try {
            Method theMethod = null;
            Class[] theClassTypesArray = null;
            Class[] thePrimitivesArray = null;
            String theArgumentTypeToken = null;
            String theArgumentTypesString = anAction.getTypes();
            String theMethodName = anAction.getMethod();
            Class theActionTargetClass = anActionTarget.getClass();
            if (theArgumentTypesString != null) {
                StringTokenizer theArgumentTypeTokens = new StringTokenizer(theArgumentTypesString, ",");
                theClassTypesArray = new Class[theArgumentTypeTokens.countTokens()];
                thePrimitivesArray = new Class[theArgumentTypeTokens.countTokens()];
                int theArgumentTypeIndex = 0;
                while (theArgumentTypeTokens.hasMoreTokens()) {
                    theArgumentTypeToken = theArgumentTypeTokens.nextToken().trim();
                    this.resolveArgumentType(theArgumentTypeIndex, theArgumentTypeToken, theClassTypesArray, thePrimitivesArray);
                    theArgumentTypeIndex++;
                }
                theMethod = theActionTargetClass.getMethod(theMethodName, thePrimitivesArray);
            } else {
                theMethod = theActionTargetClass.getMethod(theMethodName, null);
            }
            if (theMethod != null) {
                this.execute(theMethod, anAction, anActionTarget, anEventOwnerName, anEventListener, theClassTypesArray);
            }
        } catch (NoSuchMethodException e) {
            System.out.println("Syntax error:The method " + anAction.getMethod() + " for the action in the listener " + anEventListener.getEvent() + " in the element " + anEventOwnerName + "  wasn't found. Verify the value of METHOD and TYPES.");
        } catch (ClassNotFoundException e) {
            System.out.println("Syntax error:An incorrect value in TYPES has been specified for the method " + anAction.getMethod() + " in the action for the listener " + anEventListener.getEvent() + " in the element " + anEventOwnerName + ".");
        }
    }

    public void resolveArgumentType(int anArgumentTypeIndex, String anArgumentTypeToken, Class[] aClassTypesArray, Class[] aPrimitivesArray) throws ClassNotFoundException {
        if (anArgumentTypeToken.equals(Constants.PRIMITIVE_INTEGER)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.INTEGER_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Integer.TYPE;
        } else if (anArgumentTypeToken.equals(Constants.INTEGER)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.INTEGER_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Class.forName(Constants.INTEGER_WRAPPER);
        } else if (anArgumentTypeToken.equals(Constants.PRIMITIVE_BOOLEAN)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.BOOLEAN_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Boolean.TYPE;
        } else if (anArgumentTypeToken.equals(Constants.BOOLEAN)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.BOOLEAN_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Class.forName(Constants.BOOLEAN_WRAPPER);
        } else if (anArgumentTypeToken.equals(Constants.PRIMITIVE_BYTE)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.BYTE_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Byte.TYPE;
        } else if (anArgumentTypeToken.equals(Constants.BYTE)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.BYTE_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Class.forName(Constants.BYTE_WRAPPER);
        } else if (anArgumentTypeToken.equals(Constants.PRIMITIVE_FLOAT)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.FLOAT_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Float.TYPE;
        } else if (anArgumentTypeToken.equals(Constants.FLOAT)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.FLOAT_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Class.forName(Constants.FLOAT_WRAPPER);
        } else if (anArgumentTypeToken.equals(Constants.PRIMITIVE_CHAR)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.CHAR_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Character.TYPE;
        } else if (anArgumentTypeToken.equals(Constants.CHAR)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.CHAR_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Class.forName(Constants.CHAR_WRAPPER);
        } else if (anArgumentTypeToken.equals(Constants.PRIMITIVE_SHORT)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.SHORT_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Short.TYPE;
        } else if (anArgumentTypeToken.equals(Constants.SHORT)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.SHORT_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Class.forName(Constants.SHORT_WRAPPER);
        } else if (anArgumentTypeToken.equals(Constants.PRIMITIVE_LONG)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.LONG_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Long.TYPE;
        } else if (anArgumentTypeToken.equals(Constants.LONG)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.LONG_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Class.forName(Constants.LONG_WRAPPER);
        } else if (anArgumentTypeToken.equals(Constants.PRIMITIVE_DOUBLE)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.DOUBLE_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Double.TYPE;
        } else if (anArgumentTypeToken.equals(Constants.DOUBLE)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.DOUBLE_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Class.forName(Constants.DOUBLE_WRAPPER);
        } else if (anArgumentTypeToken.equals(Constants.STRING)) {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(Constants.STRING_WRAPPER);
            aPrimitivesArray[anArgumentTypeIndex] = Class.forName(Constants.STRING_WRAPPER);
        } else {
            aClassTypesArray[anArgumentTypeIndex] = Class.forName(anArgumentTypeToken);
            aPrimitivesArray[anArgumentTypeIndex] = Class.forName(anArgumentTypeToken);
        }
    }

    public void execute(Method aMethod, ActionModel anAction, Component anActionTarget, String anEventOwnerName, ListenerModel aListener, Class[] aClassTypesArray) {
        try {
            String theValuesString = anAction.getValues();
            if (theValuesString != null) {
                Constructor theArgumentTypeConstructor = null;
                Object[] theArgumentValue = new Object[1];
                Class theStringClassArray[] = { String.class };
                StringTokenizer theArgumentValues = new StringTokenizer(theValuesString, ",");
                Object[] theArgumentsArray = new Object[theArgumentValues.countTokens()];
                for (int i = 0; i < aClassTypesArray.length; i++) {
                    theArgumentTypeConstructor = aClassTypesArray[i].getConstructor(theStringClassArray);
                    theArgumentValue[0] = theArgumentValues.nextToken();
                    theArgumentsArray[i] = theArgumentTypeConstructor.newInstance(theArgumentValue);
                }
                aMethod.invoke(anActionTarget, theArgumentsArray);
            } else {
                aMethod.invoke(anActionTarget, null);
            }
        } catch (NoSuchMethodException e) {
            System.out.println("NoSuchMethodException in method EventHandler.invoke();" + e);
        } catch (InstantiationException e) {
            System.out.println("InstanttiationException in method EventHandler.invoke();" + e);
        } catch (IllegalAccessException e) {
            System.out.println("IllegalAccessException in method EventHandler.invoke();" + e);
        } catch (InvocationTargetException e) {
            System.out.println("The requested operation could not be performed due to a bad syntax error.");
        } catch (IllegalArgumentException e) {
            System.out.println("Syntax Error: The VALUES and TYPES specified for the method " + anAction.getMethod() + " in the action for the listener " + aListener.getEvent() + " in the element " + anEventOwnerName + " are incorrect.");
        }
    }

    public static EventHandler getInstance() {
        if (eventHandlerInstance == null) {
            eventHandlerInstance = new EventHandler();
        }
        return eventHandlerInstance;
    }

    protected class EventHandlerTools extends EventUtil {
        public SwingMLRenderer getRenderer(Component aComponent) {
            return super.getRenderer(aComponent);
        }
    }
}