/* SwingML
 * Copyright (C) 2002 Robert Morris.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Robert Morris <robertj@morris.net>
 *
 */

package org.swingml.event;

/**
 *
 * This interface indicates to the EventHandler that 
 * its implementers should be retained in memory rather
 * than instantiated with each invocation.
 * 
 * @author <a href="mailto:robertj@morris.net">Robert J. Morris</a>
 * 
 * @see org.swingml.event.InvokableEvent
 * @see org.swingml.event.EventHandler
 * @see org.swingml.event.ExternalEventManager
 */
public interface RetainedInMemory {
    public static int MEM_VOLATILE = 0;
    public static int MEM_GLOBAL = 1;
    public static int MEM_DOCUMENT = 2;

    /**
     * Returns one of the following values to the 
     * ExternalEventManager indicating how the implementing 
     * object should be stored:
     * 
     * MEM_VOLATILE - Only Keep this object for each invocation.  Otherwise
     * release it.
     * 
     * MEM_GLOBAL - Keep this object in the global cache, available for all 
     * documents to use.
     * 
     * MEM_DOCUMENT - Keep this object in the document-level cache.  Objects
     * in the document-level cache are released when their associated document
     * goes out of scope.
     * 
     * @return An int indicating how the ExternalEventManager
     * should retain this instance in memory.
     * 
     * @see org.swingml.event.ExternalEventManager
     */
    public int retainInMemory();
}