/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.model;

import org.swingml.Constants;
import org.swingml.SwingMLModel;

public class ButtonGroupModel extends SwingMLModel {

    private int rows = -1;
    private int cols = -1;
    private int bevelType = -1;
    private String border = null;

    public void validate() {
        if (super.getParent().getLayout() != null && super.getParent().getLayout().equalsIgnoreCase(Constants.BORDERLAYOUT)) {
            if (super.getOrientation() == null) {
                System.out.println("Syntax error: The parameter ORIENTATION in the element " + super.getName() + " is required since its parent's LAYOUT is BorderLayout. Add the parameter ORIENTATION to the element " + super.getName() + " or change its parent's LAYOUT to other than BorderLayout.");
            }
        }
        if (super.getParent().getLayout() != null && !super.getParent().getLayout().equalsIgnoreCase(Constants.BORDERLAYOUT)) {
            if (super.getOrientation() != null) {
                System.out.println("Syntax error: The parameter ORIENTATION in the element " + super.getName() + " should be used only when its parent's LAYOUT is BorderLayout. Change its parent's LAYOUT to BorderLayout or delete the parameter ORIENTATION from the element " + super.getName() + ".");
            }
        }
        if (this.border.equalsIgnoreCase(Constants.BEVELBORDER)) {
            if (this.bevelType == -1) {
                System.out.println("Syntax error: The parameter BEVELTYPE in the element " + super.getName() + " is required since the since its BORDER is BevelBorder. Add the parameter BEVELTYPE to the element " + super.getName() + " or change its BORDER to other than BevelBorder");
            }
        }
        if (!this.border.equalsIgnoreCase(Constants.BEVELBORDER)) {
            if (this.bevelType != -1) {
                System.out.println("Syntax error: The parameter BEVELTYPE in element " + super.getName() + " should be used only when its BORDER type is BevelBorder. Change its BORDER to BevelBorder or delete the parameter BEVELTYPE from the element " + super.getName() + ".");
            }
        }
        if (super.getParent() instanceof JTabbedPaneModel && super.getText() == null) {
            System.out.println("Syntax error: The parameter TEXT is missing in the element " + super.getName() + ". Add the TEXT parameter to name the TAB.");
        }
        if (this.getLayout().equalsIgnoreCase(Constants.GRIDLAYOUT)) {
            if (this.rows == 0 || this.cols == 0) {
                System.out.println("Syntax error: The value of the parameter ROWS or COLS in the element " + super.getName() + " should be numeric and greater than 0");
            }
            if (this.rows == -1 || this.cols == -1) {
                System.out.println("Syntax error: The parameter ROWS or COLS in the element " + super.getName() + " should be used since the parent's layout is GridLayout. Add the parameter ROWS or COLS.");
            }
        }
        if (!this.getLayout().equalsIgnoreCase(Constants.GRIDLAYOUT)) {
            if (this.rows != -1 || this.cols != -1) {
                System.out.println("Syntax error: The parameters ROWS or COLS in the element " + super.getName() + " are not allowed since its parent's layout is not GridLayout. Remove the parameter ROWS or COLS.");
            }
        }
        if (super.getParent() instanceof JSplitPaneModel && super.getOrientation() != null) {
            System.out.println("Syntax error: The parameters ORIENTATION in the element " + super.getName() + " is not allowed since its parent's layout is a JSplitPane. Remove the parameter ORIENTATION or put this element into a different container.");
        }
    }

    public int getBevelType() {
        return this.bevelType;
    }

    public String getBorder() {
        return this.border;
    }

    public int getCols() {
        return this.cols;
    }

    public int getRows() {
        return this.rows;
    }

    public void setBevelType(int aBevelType) {
        this.bevelType = aBevelType;
    }

    public void setBorder(String aBorder) {
        this.border = aBorder;
    }

    public void setCols(int aCols) {
        this.cols = aCols;
    }

    public void setRows(int aRows) {
        this.rows = aRows;
    }
}