/* SwingML
 * Copyright (C) 2002 Robert Morris.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Robert Morris <robertj@morris.net>
 *
 */

package org.swingml.model;

import java.awt.GridBagConstraints;
import java.util.List;
import java.util.Vector;

/**
 * This class contains the settings and some utility methods that describe the
 * data passed in from the SwingML document and should therefore be provided 
 * to a GridBagCellComponent object.
 *  
 * @see org.swingml.component.GridBagCellComponent
 */
public class GridBagCellModel extends GridBagBaseModel {
    private Vector m_children = null;
    private int m_column = -1;
    private int m_row = -1;

    /**
     * Retrieves a valid instance of the @see java.awt.GridBagConstraints 
     * class.  This GridBagConstaints instance is applied to all components
     * in the Vector returned by the getChildren() method.
     */
    public GridBagConstraints getConstraints() {
        GridBagConstraints theCon = super.getConstraints();
        theCon.gridy = this.m_row;
        theCon.gridx = this.m_column;

        return theCon;
    }

    /**
     * Sets the vertical space within a GridBagLayout to place all contained components.
     * 
     * @param	row	The vertical coordinate within the GridBagLayout to place all contained 
     * components.
     */
    public void setRow(int aRow) {
        this.m_row = aRow;
    }

    /**
     * Sets the horizontal space within a GridBagLayout to place all contained components.
     * 
     * @param	column	The horizontal coordinate within the GridBagLayout to place all
     * contained components.
     */
    public void setColumn(int aColumn) {
        this.m_column = aColumn;
    }

    /**
     * @see swingml.model.ContainerModel#addChild(Object)
     */
    public void addChild(Object anObject) {
        this.getChildren().add(anObject);
    }

    /**
     * @see swingml.model.ContainerModel#getChildren()
     */
    public List getChildren() {
        if (this.m_children == null) {
            this.m_children = new Vector();
        }
        return this.m_children;
    }

    /**
     * @see swingml.model.ContainerModel#getLayout()
     */
    public String getLayout() {
        return null;
    }

    /**
     * @see org.swingml.SwingMLModel#validate()
     */
    public void validate() {
        super.validate();
    }
}