/* SwingML
 * Copyright (C) 2002 Robert Morris.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Robert Morris <robertj@morris.net>
 *
 */

package org.swingml.model;

import java.awt.GridBagConstraints;
import java.util.List;
import java.util.Vector;

public class GridBagRowModel extends GridBagBaseModel {
    private Vector m_children = null;
    private int m_row = -1;
    private int m_currentCol = 0;

    public GridBagConstraints getConstraints() {
        GridBagConstraints theCon = super.getConstraints();
        theCon.gridy = this.m_row;
        return theCon;
    }

    public void setRow(int aRow) {
        this.m_row = aRow;
    }

    /**
     * @see swingml.model.ContainerModel#addChild(Object)
     */
    public void addChild(Object aChild) {
        // Make sure that those values set for this parent 
        // object are passed on the contained child object, 
        // if it is an instance of the GridBagBaseModel class.
        if (aChild instanceof GridBagCellModel) {
            GridBagCellModel theCellModel = (GridBagCellModel) aChild;
            theCellModel.setValues(this);
            theCellModel.setColumn(this.m_currentCol);
            theCellModel.setRow(this.m_row);
            this.m_currentCol++;
        }
        this.getChildren().add(aChild);
    }

    /**
     * @see swingml.model.ContainerModel#getChildren()
     */
    public List getChildren() {
        if (this.m_children == null) {
            this.m_children = new Vector();
        }
        return this.m_children;
    }

    /**
     * @see swingml.model.ContainerModel#getLayout()
     */
    public String getLayout() {
        return null;
    }

    public void validate() {
        super.validate();
    }
}