/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.model;

import org.swingml.Constants;
import org.swingml.SwingMLModel;

public class JFrameModel extends SwingMLModel {
    private int width = -1;
    private int height = -1;
    private int rows = -1;
    private int cols = -1;

    public int getCols() {
        return this.cols;
    }

    public int getHeight() {
        return this.height;
    }

    public int getRows() {
        return this.rows;
    }

    public int getWidth() {
        return this.width;
    }

    public void setCols(int aCols) {
        this.cols = aCols;
    }

    public void setHeight(int aHeight) {
        this.height = aHeight;
    }

    public void setRows(int aRows) {
        this.rows = aRows;
    }

    public void setWidth(int aWidth) {
        this.width = aWidth;
    }

    public void validate() {
        if (this.getLayout().equalsIgnoreCase(Constants.GRIDLAYOUT)) {
            if (this.rows == 0 || this.cols == 0) {
                System.out.println("Syntax error: The value of the parameter ROWS or COLS in the element " + super.getName() + " should be numeric and greater than 0");
            }
            if (this.rows == -1 || this.cols == -1) {
                System.out.println("Syntax error: The parameter ROWS or COLS in the element " + super.getName() + " should be used since the parent's layout is GridLayout. Add the parameter ROWS or COLS.");
            }
        }
        if (!this.getLayout().equalsIgnoreCase(Constants.GRIDLAYOUT)) {
            if (this.rows != -1 || this.cols != -1) {
                System.out.println("Syntax error: The parameters ROWS or COLS in the element " + super.getName() + " are not allowed since its parent's layout is not GridLayout. Remove the parameter ROWS or COLS.");
            }
        }
    }
}