/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.model;

import java.util.ArrayList;
import java.util.Iterator;

import org.swingml.Constants;
import org.swingml.SwingMLModel;


public class JListModel extends SwingMLModel {
    private int mode = 0;
    private int[] indexes = null;
    private boolean dndEnabled = false;
    private String postStyle = Constants.POST_SELECTED;

    public String getPostStyle() {
        return this.postStyle;
    }

    public void setPostStyle(String aPostStyle) {
        this.postStyle = aPostStyle;
    }

    public int getMode() {
        return mode;
    }

    public void setMode(int aMode) {
        this.mode = aMode;
    }

    public int[] getSelectedIndexes() {
        if (indexes == null) {
            ArrayList theIndexes = new ArrayList();
            Iterator theItems = super.getChildren().iterator();
            ItemModel theItem = null;
            while (theItems.hasNext()) {
                theItem = (ItemModel) theItems.next();
                if (theItem.isSelected()) {
                    theIndexes.add(super.getChildren().indexOf(theItem) + "");
                }
            }
            indexes = new int[theIndexes.size()];
            for (int i = 0; i < theIndexes.size(); i++) {
                indexes[i] = Integer.parseInt(theIndexes.get(i).toString());
            }
        }
        return indexes;
    }

    public void setSelectedIndexes(int[] aIndices) {
        this.indexes = aIndices;
    }

    public void validate() {
        if (super.getParent().getLayout() != null && super.getParent().getLayout().equalsIgnoreCase(Constants.BORDERLAYOUT)) {
            if (super.getOrientation() == null) {
                System.out.println("Syntax error: The parameter ORIENTATION in the element " + super.getName() + " is required since its parent's LAYOUT is BorderLayout. Add the parameter ORIENTATION to the element " + super.getName() + " or change its parent's LAYOUT to other than BorderLayout.");
            }
        }
        if (super.getParent().getLayout() != null && !super.getParent().getLayout().equalsIgnoreCase(Constants.BORDERLAYOUT)) {
            if (super.getOrientation() != null) {
                System.out.println("Syntax error: The parameter ORIENTATION in the element " + super.getName() + " should be used only when its parent's LAYOUT is BorderLayout. Change its parent's LAYOUT to BorderLayout or delete the parameter ORIENTATION from the element " + super.getName() + ".");
            }
        }
    }

    public boolean isDndEnabled() {
        return this.dndEnabled;
    }

    public void setDndEnabled(boolean aDndEnabled) {
        this.dndEnabled = aDndEnabled;
    }
}