/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.model;

import java.util.Iterator;
import java.util.List;
import java.util.Vector;

import javax.swing.ListSelectionModel;
import javax.swing.event.TableModelListener;
import javax.swing.table.TableModel;

import org.swingml.Constants;
import org.swingml.SwingMLModel;


public class JTableModel extends SwingMLModel implements TableModel {
    private List columns = null;
    private List rows = null;
    private TableRowModel row = null;
    private TableDataModel data = null;
    private String postStyle = null;
    private int postColumn = 0;
    private int mode = ListSelectionModel.MULTIPLE_INTERVAL_SELECTION;

    public void setMode(int aMode) {
        this.mode = aMode;
    }

    public int getMode() {
        return this.mode;
    }

    public String getPostStyle() {
        return this.postStyle;
    }

    public void setPostStyle(String aPostStyle) {
        this.postStyle = aPostStyle;
    }

    public int getPostColumn() {
        return this.postColumn;
    }

    public void setPostColumn(int aPostColumn) {
        this.postColumn = aPostColumn;
    }

    public void addChild(Object aChild) {
        if (aChild instanceof TableColumnModel) {
            this.getColumns().add(aChild);
        }
        if (aChild instanceof TableRowModel) {
            this.getRows().add(aChild);
        }
    }

    public List getColumns() {
        if (this.columns == null) {
            this.columns = new Vector();
        }
        return columns;
    }

    public List getRows() {
        if (this.rows == null) {
            this.rows = new Vector();
        }
        return rows;
    }

    public void validate() {
        if (super.getParent().getLayout() != null && super.getParent().getLayout().equalsIgnoreCase(Constants.BORDERLAYOUT)) {
            if (super.getOrientation() == null) {
                System.out.println("Syntax error: The parameter ORIENTATION in the element " + super.getName() + " is required since its parent's LAYOUT is BorderLayout. Add the parameter ORIENTATION to the element " + super.getName() + " or change its parent's LAYOUT to other than BorderLayout.");
            }
        }

        if (super.getParent().getLayout() != null && !super.getParent().getLayout().equalsIgnoreCase(Constants.BORDERLAYOUT)) {
            if (super.getOrientation() != null) {
                System.out.println("Syntax error: The parameter ORIENTATION in the element " + super.getName() + " should be used only when its parent's LAYOUT is BorderLayout. Change its parent's LAYOUT to BorderLayout or delete the parameter ORIENTATION from the element " + super.getName() + ".");
            }
        }

        Iterator theColumns = this.getColumns().iterator();
        TableColumnModel theTableColumnModel = null;
        while (theColumns.hasNext()) {
            theTableColumnModel = (TableColumnModel) theColumns.next();
            theTableColumnModel.validate();
        }

        Iterator theData = null;
        TableRowModel theTableRowModel = null;
        TableDataModel theTableDataModel = null;
        Iterator theRows = this.getRows().iterator();
        while (theRows.hasNext()) {
            theTableRowModel = (TableRowModel) theRows.next();
            theData = theTableRowModel.getChildren().iterator();
            while (theData.hasNext()) {
                theTableDataModel = (TableDataModel) theData.next();
                theTableDataModel.validate();
            }
        }
    }

    /*
     * @TableModel realization starts here.
     */
    public int getRowCount() {
        return this.getRows().size();
    }

    public int getColumnCount() {
        return this.getColumns().size();
    }

    public String getColumnName(int aColumnIndex) {
        TableColumnModel theTableColumnModel = (TableColumnModel) this.getColumns().get(aColumnIndex);
        return theTableColumnModel.getText();
    }

    public Class getColumnClass(int aColumnIndex) {
        TableColumnModel theTableColumnModel = (TableColumnModel) this.getColumns().get(aColumnIndex);
        return theTableColumnModel.getType().getClass();
    }

    public boolean isCellEditable(int aRowIndex, int aColumnIndex) {
        this.row = (TableRowModel) getRows().get(aRowIndex);
        this.data = (TableDataModel) row.getChildren().get(aColumnIndex);
        return this.data.isEditable();
    }

    public Object getValueAt(int aRowIndex, int aColumnIndex) {
        this.row = (TableRowModel) getRows().get(aRowIndex);
        this.data = (TableDataModel) row.getChildren().get(aColumnIndex);
        return this.data.getValue();
    }

    public void setValueAt(Object aValue, int aRowIndex, int aColumnIndex) {
        this.row = (TableRowModel) getRows().get(aRowIndex);
        this.data = (TableDataModel) row.getChildren().get(aColumnIndex);
        this.data.setValue(aValue);
    }

    public void addTableModelListener(TableModelListener l) {
    }

    public void removeTableModelListener(TableModelListener l) {
    }
}