/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *     Farid Ibrahim <faridibrahim@lycos.com>
 * 
 */

package org.swingml.model;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.component.ColorComponent;


public class JTextFieldModel extends SwingMLModel {
    private String cols = null;
    private ColorComponent foreground = null;
    private ColorComponent background = null;
    private boolean editable = true;
    private boolean enabled = true;

    public void setEnabled(boolean aEnabled) {
        this.enabled = aEnabled;
    }

    public boolean isEnabled() {
        return this.enabled;
    }

    public String getCols() {
        return this.cols;
    }

    public void setCols(String aColumns) {
        this.cols = aColumns;
    }

    public boolean isEditable() {
        return this.editable;
    }

    public void setEditable(boolean aEditable) {
        this.editable = aEditable;
    }

    public ColorComponent getBackground() {
        return this.background;
    }

    public ColorComponent getForeground() {
        return this.foreground;
    }

    public void setBackground(ColorComponent aComponent) {
        background = aComponent;
    }

    public void setForeground(ColorComponent aComponent) {
        foreground = aComponent;
    }

    public void validate() {
        if (super.getParent().getLayout() != null && super.getParent().getLayout().equalsIgnoreCase(Constants.BORDERLAYOUT)) {
            if (super.getOrientation() == null) {
                System.out.println("Syntax error: The parameter ORIENTATION in the element " + super.getName() + " is required since its parent's LAYOUT is BorderLayout. Add the parameter ORIENTATION to the element " + super.getName() + " or change its parent's LAYOUT to other than BorderLayout.");
            }
        }
        if (super.getParent().getLayout() != null && !super.getParent().getLayout().equalsIgnoreCase(Constants.BORDERLAYOUT)) {
            if (super.getOrientation() != null) {
                System.out.println("Syntax error: The parameter ORIENTATION in the element " + super.getName() + " should be used only when its parent's LAYOUT is BorderLayout. Change its parent's LAYOUT to BorderLayout or delete the parameter ORIENTATION from the element " + super.getName() + ".");
            }
        }
        try {
            Integer.parseInt(this.cols);
        } catch (NumberFormatException e) {
            this.cols = "0";
            System.out.println("Syntax error: The parameter COLS in the element " + super.getName() + " should be a numeric value.");
        }
    }
}