/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.model;

import java.util.Vector;

import javax.swing.JComboBox;

import org.swingml.SwingMLModel;
import org.swingml.component.ColorComponent;


public class TableDataModel extends SwingMLModel {

    private Object value = null;
    private TableColumnModel column = null;
    private boolean editable = false;

    public Object getValue() {
        return this.value;
    }

    public void setValue(Object aValue) {
        this.value = aValue;
    }

    public void setColumn(int aColumnIndex) {
        JTableModel theTableModel = (JTableModel) super.getParent().getParent();
        this.column = (TableColumnModel) theTableModel.getColumns().get(aColumnIndex);
    }

    public TableColumnModel getColumn() {
        return this.column;
    }

    public boolean isEditable() {
        return this.editable;
    }

    public void setEditable(boolean aEditable) {
        this.editable = aEditable;
    }

    public void validate() {
        if (this.getColumn().getType().getClass().equals(JComboBox.class)) {
            Vector theItems = this.getColumn().getItems();
            if (theItems != null) {
                if (!theItems.contains(this.getValue().toString())) {
                    System.out.println("Syntax error: The VALUE " + this.getValue() + " specified in the TD element of the TC with text " + getColumn().getText() + " does not match one of the values specified in the ITEMS parameter.");
                }
            }
        }

        if (this.getColumn().getType().getClass().equals(ColorComponent.class)) {
            Vector theItems = this.getColumn().getItems();
            if (theItems != null) {
                if (this.getValue() == null) {
                    System.out.println("Syntax error: The VALUE specified in the TD element of the TC with text " + getColumn().getText() + " does not match one of the values specified in the ITEMS parameter.");
                }
            }
        }
    }
}