/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *     Robert Morris <robertj@morris.net>  
 *     Bram Stieperaere <bramez@users.sourceforge.net>
 * 	   Marcelo W. Lopez Cremona <marcelo_java@argentina.com> 
 *     Hamdi Mohs Yusof <hamdi@medical-online.net>         
 */

package org.swingml.view;

import java.awt.Container;
import java.util.List;

import org.swingml.SwingMLModel;
import org.swingml.model.ButtonGroupModel;
import org.swingml.model.DataStoreModel;
import org.swingml.model.GridBagCellModel;
import org.swingml.model.GridBagPanelModel;
import org.swingml.model.GridBagRowModel;
import org.swingml.model.JButtonModel;
import org.swingml.model.JCheckBoxModel;
import org.swingml.model.JComboBoxModel;
import org.swingml.model.JDebugModel;
import org.swingml.model.JDialogModel;
import org.swingml.model.JEditorPaneModel;
import org.swingml.model.JFrameModel;
import org.swingml.model.JInternalFrameModel;
import org.swingml.model.JLabelModel;
import org.swingml.model.JListModel;
import org.swingml.model.JMenuBarModel;
import org.swingml.model.JMenuItemModel;
import org.swingml.model.JMenuModel;
import org.swingml.model.JOptionPaneModel;
import org.swingml.model.JPanelModel;
import org.swingml.model.JPasswordModel;
import org.swingml.model.JRadioButtonModel;
import org.swingml.model.JSeparatorModel;
import org.swingml.model.JSliderModel;
import org.swingml.model.JSplitPaneModel;
import org.swingml.model.JTabbedPaneModel;
import org.swingml.model.JTableModel;
import org.swingml.model.JTextAreaModel;
import org.swingml.model.JTextFieldModel;
import org.swingml.model.JToolBarModel;
import org.swingml.model.JTreeModel;
import org.swingml.view.renderer.ButtonGroupRenderer;
import org.swingml.view.renderer.DataStoreRenderer;
import org.swingml.view.renderer.GridBagCellRenderer;
import org.swingml.view.renderer.GridBagPanelRenderer;
import org.swingml.view.renderer.GridBagRowRenderer;
import org.swingml.view.renderer.JButtonRenderer;
import org.swingml.view.renderer.JCheckBoxRenderer;
import org.swingml.view.renderer.JComboBoxRenderer;
import org.swingml.view.renderer.JDebugRenderer;
import org.swingml.view.renderer.JDialogRenderer;
import org.swingml.view.renderer.JEditorPaneRenderer;
import org.swingml.view.renderer.JFrameRenderer;
import org.swingml.view.renderer.JInternalFrameRenderer;
import org.swingml.view.renderer.JLabelRenderer;
import org.swingml.view.renderer.JListRenderer;
import org.swingml.view.renderer.JMenuBarRenderer;
import org.swingml.view.renderer.JMenuItemRenderer;
import org.swingml.view.renderer.JMenuRenderer;
import org.swingml.view.renderer.JOptionPaneRenderer;
import org.swingml.view.renderer.JPanelRenderer;
import org.swingml.view.renderer.JPasswordRenderer;
import org.swingml.view.renderer.JRadioButtonRenderer;
import org.swingml.view.renderer.JSeparatorRenderer;
import org.swingml.view.renderer.JSliderRenderer;
import org.swingml.view.renderer.JSplitPaneRenderer;
import org.swingml.view.renderer.JTabbedPaneRenderer;
import org.swingml.view.renderer.JTableRenderer;
import org.swingml.view.renderer.JTextAreaRenderer;
import org.swingml.view.renderer.JTextFieldRenderer;
import org.swingml.view.renderer.JToolBarRenderer;
import org.swingml.view.renderer.JTreeRenderer;


public class RendererUtil {
    public Renderer getRenderer(Object aChild) {
        Renderer theRenderer = null;
        if (aChild instanceof JPanelModel) {
            theRenderer = new JPanelRenderer();
        }
        if (aChild instanceof JMenuBarModel) {
            theRenderer = new JMenuBarRenderer();
        }
        if (aChild instanceof JMenuModel) {
            theRenderer = new JMenuRenderer();
        }
        if (aChild instanceof JMenuItemModel) {
            theRenderer = new JMenuItemRenderer();
        }
        if (aChild instanceof JSeparatorModel) {
            theRenderer = new JSeparatorRenderer();
        }
        if (aChild instanceof JDialogModel) {
            theRenderer = new JDialogRenderer();
        }
        if (aChild instanceof JFrameModel) {
            theRenderer = new JFrameRenderer();
        }
        if (aChild instanceof JTextFieldModel) {
            theRenderer = new JTextFieldRenderer();
        }
        if (aChild instanceof JButtonModel) {
            theRenderer = new JButtonRenderer();
        }
        if (aChild instanceof JToolBarModel) {
            theRenderer = new JToolBarRenderer();
        }
        if (aChild instanceof JTabbedPaneModel) {
            theRenderer = new JTabbedPaneRenderer();
        }
        if (aChild instanceof JLabelModel) {
            theRenderer = new JLabelRenderer();
        }
        if (aChild instanceof JTreeModel) {
            theRenderer = new JTreeRenderer();
        }
        if (aChild instanceof JTableModel) {
            theRenderer = new JTableRenderer();
        }
        if (aChild instanceof JComboBoxModel) {
            theRenderer = new JComboBoxRenderer();
        }
        if (aChild instanceof JListModel) {
            theRenderer = new JListRenderer();
        }
        if (aChild instanceof JCheckBoxModel) {
            theRenderer = new JCheckBoxRenderer();
        }
        if (aChild instanceof JRadioButtonModel) {
            theRenderer = new JRadioButtonRenderer();
        }
        if (aChild instanceof ButtonGroupModel) {
            theRenderer = new ButtonGroupRenderer();
        }
        if (aChild instanceof JTextAreaModel) {
            theRenderer = new JTextAreaRenderer();
        }
        if (aChild instanceof JEditorPaneModel) {
            theRenderer = new JEditorPaneRenderer();
        }
        if (aChild instanceof JOptionPaneModel) {
            theRenderer = new JOptionPaneRenderer();
        }
        if (aChild instanceof JInternalFrameModel) {
            theRenderer = new JInternalFrameRenderer();
        }
        if (aChild instanceof JSplitPaneModel) {
            theRenderer = new JSplitPaneRenderer();
        }
        if (aChild instanceof GridBagPanelModel) {
            theRenderer = new GridBagPanelRenderer();
        }
        if (aChild instanceof GridBagRowModel) {
            theRenderer = new GridBagRowRenderer();
        }
        if (aChild instanceof GridBagCellModel) {
            theRenderer = new GridBagCellRenderer();
        }
        if (aChild instanceof JDebugModel) {
            theRenderer = new JDebugRenderer();
        }
        if (aChild instanceof JPasswordModel) {
            theRenderer = new JPasswordRenderer();
        }
        if (aChild instanceof DataStoreModel) {
            theRenderer = new DataStoreRenderer();
        }
        if (aChild instanceof JSliderModel) {
            theRenderer = new JSliderRenderer();
        }
        return theRenderer;
    }

    public void iterate(Object aModel, Container aParent) {
        SwingMLModel theContainer = (SwingMLModel) aModel;
        List theChildren = theContainer.getChildren();
        Renderer theRenderer = null;
        SwingMLModel theChild = null;
        for (int i = 0; i < theChildren.size(); i++) {
            theChild = (SwingMLModel) theChildren.get(i);
            theChild.validate();
            theRenderer = this.getRenderer(theChild);
            if (theRenderer != null) {
                theRenderer.render(theChild, aParent);
            }
        }
    }
}