/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *     Robert Morris <robertj@morris.net>
 *     Bram Stieperaere <bramez@users.sourceforge.net>
 * 	   Marcelo W. Lopez Cremona <marcelo_java@argentina.com> 
 */

package org.swingml.xml;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.FactoryConfigurationError;
import javax.xml.parsers.ParserConfigurationException;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.URLHandler;
import org.swingml.xml.mapper.ActionMapper;
import org.swingml.xml.mapper.ActionParamMapper;
import org.swingml.xml.mapper.ButtonGroupMapper;
import org.swingml.xml.mapper.DataStoreMapper;
import org.swingml.xml.mapper.ExternalActionMapper;
import org.swingml.xml.mapper.GridBagCellMapper;
import org.swingml.xml.mapper.GridBagPanelMapper;
import org.swingml.xml.mapper.GridBagRowMapper;
import org.swingml.xml.mapper.ItemMapper;
import org.swingml.xml.mapper.JButtonMapper;
import org.swingml.xml.mapper.JCheckBoxMapper;
import org.swingml.xml.mapper.JComboBoxMapper;
import org.swingml.xml.mapper.JDebugMapper;
import org.swingml.xml.mapper.JDialogMapper;
import org.swingml.xml.mapper.JEditorPaneMapper;
import org.swingml.xml.mapper.JFrameMapper;
import org.swingml.xml.mapper.JInternalFrameMapper;
import org.swingml.xml.mapper.JLabelMapper;
import org.swingml.xml.mapper.JListMapper;
import org.swingml.xml.mapper.JMenuBarMapper;
import org.swingml.xml.mapper.JMenuItemMapper;
import org.swingml.xml.mapper.JMenuMapper;
import org.swingml.xml.mapper.JOptionPaneMapper;
import org.swingml.xml.mapper.JPanelMapper;
import org.swingml.xml.mapper.JPasswordMapper;
import org.swingml.xml.mapper.JRadioButtonMapper;
import org.swingml.xml.mapper.JSeparatorMapper;
import org.swingml.xml.mapper.JSliderMapper;
import org.swingml.xml.mapper.JSplitPaneMapper;
import org.swingml.xml.mapper.JTabbedPaneMapper;
import org.swingml.xml.mapper.JTableMapper;
import org.swingml.xml.mapper.JTextAreaMapper;
import org.swingml.xml.mapper.JTextFieldMapper;
import org.swingml.xml.mapper.JToolBarMapper;
import org.swingml.xml.mapper.JTreeMapper;
import org.swingml.xml.mapper.ListenerMapper;
import org.swingml.xml.mapper.NodeMapper;
import org.swingml.xml.mapper.TableColumnMapper;
import org.swingml.xml.mapper.TableDataMapper;
import org.swingml.xml.mapper.TableRowMapper;
import org.w3c.dom.Document;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;


public class MapperUtil {
    public Node getAttribute(Node aNode, String aNodeName) {
        NamedNodeMap theAttributes = aNode.getAttributes();
        Node theAttribute = null;
        for (int i = 0; i < theAttributes.getLength(); i++) {
            aNode = theAttributes.item(i);
            if (aNode.getNodeName().equalsIgnoreCase(aNodeName)) {
                theAttribute = aNode;
                break;
            } 
        }
        return theAttribute;
    }

    public Mapper getMapper(String aNodeName) {
        Mapper theMapper = null;
        if (aNodeName.equalsIgnoreCase(Constants.PANEL)) {
            theMapper = new JPanelMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.MENUBAR)) {
            theMapper = new JMenuBarMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.MENU)) {
            theMapper = new JMenuMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.MENUITEM)) {
            theMapper = new JMenuItemMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.SEPARATOR)) {
            theMapper = new JSeparatorMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.DIALOG)) {
            theMapper = new JDialogMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.FRAME)) {
            theMapper = new JFrameMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.TEXTFIELD)) {
            theMapper = new JTextFieldMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.BUTTON)) {
            theMapper = new JButtonMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.TOOLBAR)) {
            theMapper = new JToolBarMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.TABBEDPANE)) {
            theMapper = new JTabbedPaneMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.LABEL)) {
            theMapper = new JLabelMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.TREE)) {
            theMapper = new JTreeMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.NODE)) {
            theMapper = new NodeMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.TABLE)) {
            theMapper = new JTableMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.TC)) {
            theMapper = new TableColumnMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.TR)) {
            theMapper = new TableRowMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.TD)) {
            theMapper = new TableDataMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.COMBOBOX)) {
            theMapper = new JComboBoxMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.CHECKBOX)) {
            theMapper = new JCheckBoxMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.BUTTONGROUP)) {
            theMapper = new ButtonGroupMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.RADIOBUTTON)) {
            theMapper = new JRadioButtonMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.INTERNALFRAME)) {
            theMapper = new JInternalFrameMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.TEXTAREA)) {
            theMapper = new JTextAreaMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.EDITORPANE)) {
            theMapper = new JEditorPaneMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.OPTIONPANE)) {
            theMapper = new JOptionPaneMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.LIST)) {
            theMapper = new JListMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.ITEM)) {
            theMapper = new ItemMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.LISTENER)) {
            theMapper = new ListenerMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.ACTION)) {
            theMapper = new ActionMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.SPLITPANE)) {
            theMapper = new JSplitPaneMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.GRIDBAG_PANEL)) {
            theMapper = new GridBagPanelMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.GRIDBAG_ROW)) {
            theMapper = new GridBagRowMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.GRIDBAG_CELL)) {
            theMapper = new GridBagCellMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.DEBUG)) {
            theMapper = new JDebugMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.EXTERNAL_ACTION)) {
            theMapper = new ExternalActionMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.ACTION_PARAM)) {
            theMapper = new ActionParamMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.PASSWORDTEXT)) {
            theMapper = new JPasswordMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.DATASTORE)) {
            theMapper = new DataStoreMapper();
        }
        if (aNodeName.equalsIgnoreCase(Constants.SLIDER)) {
            theMapper = new JSliderMapper();
        }
        return theMapper;
    }

    public void iterate(Node aNode, Object aModel) {
        Mapper theMapper = null;
        int theNodeType = 0;
        NodeList theNodes = aNode.getChildNodes();
        for (int i = 0; i < theNodes.getLength(); i++) {
            aNode = theNodes.item(i);
            theNodeType = aNode.getNodeType();
            if (theNodeType == Node.ELEMENT_NODE) {
                theMapper = this.getMapper(aNode.getNodeName());
                if (theMapper != null) {
                    theMapper.mapModel(aNode, aModel);
                }
            }
        }
    }

    public Document parse(String aSpec) {
        try {
            InputStream theXmlInputStream = new ByteArrayInputStream(aSpec.getBytes());
            InputSource theXmlSourceStream = new InputSource(theXmlInputStream);
            theXmlSourceStream.setSystemId(URLHandler.codebase.toString());
            DocumentBuilderFactory theFactory = DocumentBuilderFactory.newInstance();
            theFactory.setValidating(true);
            DocumentBuilder theBuilder = theFactory.newDocumentBuilder();
            Document theDocument = theBuilder.parse(theXmlSourceStream);
            return theDocument;
        } catch (FactoryConfigurationError e) {
            System.out.println(e);
        } catch (ParserConfigurationException e) {
            System.out.println(e);
        } catch (SAXException e) {
            System.out.println(e);
        } catch (IOException e) {
            System.out.println(e);
        }
        return null;
    }

    public void mapCommonAttributes(SwingMLModel aModel, Node aNode) {
        Node theResultNode = null;
        theResultNode = this.getAttribute(aNode, Constants.NAME);
        if (theResultNode != null) {
            aModel.setName(theResultNode.getNodeValue());
        }
        theResultNode = this.getAttribute(aNode, Constants.TEXT);
        if (theResultNode != null) {
            aModel.setText(theResultNode.getNodeValue());
        }
        theResultNode = this.getAttribute(aNode, Constants.ORIENTATION);
        if (theResultNode != null) {
            aModel.setOrientation(theResultNode.getNodeValue());
        }
        theResultNode = this.getAttribute(aNode, Constants.TOOLTIP);
        if (theResultNode != null) {
            aModel.setTooltip(theResultNode.getNodeValue());
        }
        theResultNode = this.getAttribute(aNode, Constants.ICON);
        if (theResultNode != null) {
            URL url = URLHandler.handle(theResultNode.getNodeValue());
            aModel.setIcon(url.toString());
        }
        theResultNode = this.getAttribute(aNode, Constants.LAYOUT);
        if (theResultNode != null) {
            aModel.setLayout(theResultNode.getNodeValue());
        } else {
            aModel.setLayout("");
        }
    }
}