/* SwingML
 * Copyright (C) 2002 Robert Morris.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Robert Morris <robertj@morris.net>
 *
 */

package org.swingml.xml.mapper;

import org.swingml.Constants;
import org.swingml.model.ActionParamModel;
import org.swingml.model.ExternalActionModel;
import org.swingml.xml.Mapper;
import org.swingml.xml.MapperUtil;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;


/**
 * @author <a href="mailto:robertj@morris.net">Robert J. Morris</a>
 *
 */
public class ActionParamMapper extends MapperUtil implements Mapper {

    /**
     * @see org.swingml.xml.Mapper#getModelToMap(Node, Object)
     */
    public Object getModelToMap(Node aNode, Object aParent) {
        ActionParamModel theModel = new ActionParamModel();
        ExternalActionModel theActionModel = (ExternalActionModel) aParent;
        theActionModel.addParam(theModel);
        return theModel;
    }

    /**
     * @see org.swingml.xml.Mapper#mapModel(Node, Object)
     */
    public void mapModel(Node aNode, Object aParent) {
        ActionParamModel theParamModel = (ActionParamModel) this.getModelToMap(aNode, aParent);
        this.mapModelAttributes(aNode, theParamModel, aParent);
    }

    /**
     * @see org.swingml.xml.Mapper#mapModelAttributes(Node, Object, Object)
     */
    public void mapModelAttributes(Node aNode, Object aModel, Object aParent) {
        Node theResultNode = null;
        ActionParamModel theParamModel = (ActionParamModel) aModel;

        theResultNode = super.getAttribute(aNode, Constants.NAME);
        if (theResultNode != null) {
            theParamModel.setName(theResultNode.getNodeValue());
        }

        theResultNode = super.getAttribute(aNode, Constants.VALUE);
        if (theResultNode != null) {
            theParamModel.setValue(theResultNode.getNodeValue());
        }

        /*
         * If the ACTION-PARAM element contains a mutli-facted value, 
         * iterate through all of its children in order to fully extract
         * it from the source.
         */
        NodeList theNodes = aNode.getChildNodes();
        if (theNodes.getLength() > 0) {
            StringBuffer theValue = new StringBuffer();

            for (int i = 0; i < theNodes.getLength(); i++) {
                theValue.append(theNodes.item(i).getNodeValue());
            }

            if (theValue.length() > 0) {
                theParamModel.setValue(theValue.toString());
            }
        }
    }
}