/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.xml.mapper;

import javax.swing.border.BevelBorder;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.model.ButtonGroupModel;
import org.swingml.xml.Mapper;
import org.swingml.xml.MapperUtil;
import org.w3c.dom.Node;


public class ButtonGroupMapper extends MapperUtil implements Mapper {

    public Object getModelToMap(Node aNode, Object aParent) {
        ButtonGroupModel theModel = new ButtonGroupModel();
        SwingMLModel theContainer = (SwingMLModel) aParent;
        theContainer.addChild(theModel);
        theModel.setParent(theContainer);
        return theModel;
    }

    public void mapModel(Node aNode, Object aParent) {
        ButtonGroupModel theModel = (ButtonGroupModel) this.getModelToMap(aNode, aParent);
        this.mapModelAttributes(aNode, theModel, aParent);
        super.iterate(aNode, theModel);
    }

    public void mapModelAttributes(Node aNode, Object aModel, Object aParent) {
        ButtonGroupModel theButtonModel = (ButtonGroupModel) aModel;
        super.mapCommonAttributes(theButtonModel, aNode);
        Node theResultNode = null;

        theResultNode = super.getAttribute(aNode, Constants.BORDER);
        if (theResultNode != null) {
            theButtonModel.setBorder(theResultNode.getNodeValue());
        } else {
            theButtonModel.setBorder("");
        }
        theResultNode = super.getAttribute(aNode, Constants.BEVELTYPE);
        if (theResultNode != null) {
            int bevelType = 0;
            if (theResultNode.getNodeValue().equalsIgnoreCase(Constants.LOWERED)) {
                bevelType = BevelBorder.LOWERED;
            } else if (theResultNode.getNodeValue().equalsIgnoreCase(Constants.RAISED)) {
                bevelType = BevelBorder.RAISED;
            }
            theButtonModel.setBevelType(bevelType);
        }
        theResultNode = super.getAttribute(aNode, Constants.ROWS);
        if (theResultNode != null) {
            try {
                theButtonModel.setRows(Integer.parseInt(theResultNode.getNodeValue()));
            } catch (NumberFormatException e) {
                theButtonModel.setRows(0);
            }
        }
        theResultNode = super.getAttribute(aNode, Constants.COLS);
        if (theResultNode != null) {
            try {
                theButtonModel.setCols(Integer.parseInt(theResultNode.getNodeValue()));
            } catch (NumberFormatException e) {
                theButtonModel.setCols(0);
            }
        }
    }

}