/*
 * SwingML
 * Copyright (C) 2002 Robert J. Morris.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Robert J. Morris		<robertj@morris.net>
 */

package org.swingml.xml.mapper;

import javax.swing.border.BevelBorder;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.model.GridBagPanelModel;
import org.w3c.dom.Node;


/**
 * @author rmorris <mailto:robertj@morris.net>
 *
 */
public class GridBagPanelMapper extends GridBagBaseMapper {
    /**
     * @see org.swingml.xml.Mapper#getModelToMap(Node, Object)
     */
    public Object getModelToMap(Node aNode, Object aParent) {
        GridBagPanelModel theModel = new GridBagPanelModel();
        SwingMLModel theContainer = (SwingMLModel) aParent;
        theContainer.addChild(theModel);
        theModel.setParent(theContainer);
        return theModel;
    }

    /**
     * @see org.swingml.xml.Mapper#mapModel(Node, Object)
     */
    public void mapModel(Node aNode, Object aParent) {
        GridBagPanelModel theModel = (GridBagPanelModel) this.getModelToMap(aNode, aParent);
        this.mapModelAttributes(aNode, theModel, aParent);
        super.iterate(aNode, theModel);
    }

    /**
     * @see org.swingml.xml.Mapper#mapModelAttributes(Node, Object, Object)
     */
    public void mapModelAttributes(Node aNode, Object aModel, Object aParent) {
        super.mapModelAttributes(aNode, aModel, aParent);
        GridBagPanelModel theGridBagPanelModel = (GridBagPanelModel) aModel;
        Node theResultNode = null;
        theResultNode = super.getAttribute(aNode, Constants.BEVELTYPE);
        if (theResultNode != null) {
            int theBevelType = 0;
            if (theResultNode.getNodeValue().equalsIgnoreCase(Constants.LOWERED)) {
                theBevelType = BevelBorder.LOWERED;
            } else if (theResultNode.getNodeValue().equalsIgnoreCase(Constants.RAISED)) {
                theBevelType = BevelBorder.RAISED;
            }
            theGridBagPanelModel.setBevelType(theBevelType);
        }
        theResultNode = super.getAttribute(aNode, Constants.BORDER);
        if (theResultNode != null) {
            theGridBagPanelModel.setBorder(theResultNode.getNodeValue());
        }
        theResultNode = super.getAttribute(aNode, Constants.ORIENTATION);
        if (theResultNode != null) {
            theGridBagPanelModel.setOrientation(theResultNode.getNodeValue());
        }
    }
} 
