/*
 * SwingML
 * Copyright (C) 2002 Robert J. Morris.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     <a href="mailto:robertj@morris.net">Robert J. Morris</a>
 * 
 * Oct 9, 2002 6:51:53 PM
 */
package org.swingml.xml.mapper;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.model.JDebugModel;
import org.swingml.xml.Mapper;
import org.swingml.xml.MapperUtil;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;


/**
 *
 * Maps the values supplied in the DEBUG tag to a new 
 * JDebugModel instance
 * 
 * @see org.swingml.model.JDebugModel
 */
public class JDebugMapper extends MapperUtil implements Mapper {

    /**
     * @see org.swingml.xml.Mapper#getModelToMap(Node, Object)
     */
    public Object getModelToMap(Node aNode, Object aParent) {
        SwingMLModel theContainer = (SwingMLModel) aParent;
        JDebugModel theModel = new JDebugModel();
        theContainer.addChild(theModel);
        theModel.setParent(theContainer);
        return theModel;
    }

    /**
     * @see org.swingml.xml.Mapper#mapModel(Node, Object)
     */
    public void mapModel(Node aNode, Object aParent) {
        JDebugModel theModel = (JDebugModel) this.getModelToMap(aNode, aParent);
        this.mapModelAttributes(aNode, theModel, aParent);
        super.iterate(aNode, theModel);
    }

    /**
     * @see org.swingml.xml.Mapper#mapModelAttributes(Node, Object, Object)
     */
    public void mapModelAttributes(Node aNode, Object aModel, Object aParent) {
        JDebugModel theDebugModel = (JDebugModel) aModel;
        Node theResultNode = null;
        Node theFirstChild = null;
        NodeList theNodes = aNode.getChildNodes();
        if (theNodes != null && theNodes.getLength() > 0) {
            for (int i = 0; i < theNodes.getLength(); i++) {
                theResultNode = theNodes.item(i);
                if (theResultNode.getNodeName().equalsIgnoreCase(Constants.TEXT)) {
                    // Make sure that something is actually there before 
                    // referencing the object.
                    theFirstChild = theResultNode.getFirstChild();
                    if (theFirstChild != null) {
                        theDebugModel.setText(theFirstChild.getNodeValue());
                    }
                }
            }
        }
    }
} 