/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.xml.mapper;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.model.JDialogModel;
import org.swingml.xml.Mapper;
import org.swingml.xml.MapperUtil;
import org.w3c.dom.Node;


public class JDialogMapper extends MapperUtil implements Mapper {

    public Object getModelToMap(Node aNode, Object aParent) {
        JDialogModel theModel = new JDialogModel();
        SwingMLModel theContainer = (SwingMLModel) aParent;
        theContainer.addChild(theModel);
        theModel.setParent(theContainer);
        return theModel;
    }

    public void mapModel(Node aNode, Object aParent) {
        JDialogModel theModel = (JDialogModel) this.getModelToMap(aNode, aParent);
        this.mapModelAttributes(aNode, theModel, aParent);
        super.iterate(aNode, theModel);
    }

    public void mapModelAttributes(Node aNode, Object aModel, Object aParent) {
        JDialogModel theModel = (JDialogModel) aModel;
        super.mapCommonAttributes(theModel, aNode);
        Node theResultNode = super.getAttribute(aNode, Constants.ROWS);
        if (theResultNode != null) {
            try {
                theModel.setRows(Integer.parseInt(theResultNode.getNodeValue()));
            } catch (NumberFormatException e) {
                theModel.setRows(0);
            }
        }
        theResultNode = super.getAttribute(aNode, Constants.COLS);
        if (theResultNode != null) {
            try {
                theModel.setCols(Integer.parseInt(theResultNode.getNodeValue()));
            } catch (NumberFormatException e) {
                theModel.setCols(0);
            }
        }
        theResultNode = super.getAttribute(aNode, Constants.WIDTH);
        if (theResultNode != null) {
            try {
                theModel.setWidth(Integer.parseInt(theResultNode.getNodeValue()));
            } catch (NumberFormatException e) {
                theModel.setWidth(0);
            }
        }
        theResultNode = super.getAttribute(aNode, Constants.HEIGHT);
        if (theResultNode != null) {
            try {
                theModel.setHeight(Integer.parseInt(theResultNode.getNodeValue()));
            } catch (NumberFormatException e) {
                theModel.setHeight(0);
            }
        }

        theResultNode = super.getAttribute(aNode, Constants.MODAL);
        if (theResultNode != null) {
            String modalValue = theResultNode.getNodeValue();
            theModel.setModal((modalValue.equalsIgnoreCase(Constants.TRUE)));
        }
    }
}