/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.xml.mapper;

import java.net.URL;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.URLHandler;
import org.swingml.model.JEditorPaneModel;
import org.swingml.xml.Mapper;
import org.swingml.xml.MapperUtil;
import org.w3c.dom.Node;


public class JEditorPaneMapper extends MapperUtil implements Mapper {

    public Object getModelToMap(Node aNode, Object aParent) {
        JEditorPaneModel theModel = new JEditorPaneModel();
        SwingMLModel theContainer = (SwingMLModel) aParent;
        theContainer.addChild(theModel);
        theModel.setParent(theContainer);
        return theModel;
    }

    public void mapModel(Node aNode, Object aParent) {
        JEditorPaneModel theModel = (JEditorPaneModel) this.getModelToMap(aNode, aParent);
        this.mapModelAttributes(aNode, theModel, aParent);
    }

    public void mapModelAttributes(Node aNode, Object aModel, Object aParent) {
        JEditorPaneModel theModel = (JEditorPaneModel) aModel;
        super.mapCommonAttributes(theModel, aNode);
        Node theResultNode = super.getAttribute(aNode, Constants.PAGE);
        if (theResultNode != null) {
            URL theUrl = URLHandler.handle(theResultNode.getNodeValue());
            theModel.setPage(theUrl.toString());
        }
        theResultNode = super.getAttribute(aNode, Constants.EDITABLE);
        if (theResultNode != null) {
            theModel.setEditable(theResultNode.getNodeValue().equalsIgnoreCase(Constants.TRUE));
        }
    }

}