/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.xml.mapper;

import javax.swing.JSlider;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.model.JSliderModel;
import org.swingml.xml.Mapper;
import org.swingml.xml.MapperUtil;
import org.w3c.dom.Node;


public class JSliderMapper extends MapperUtil implements Mapper {

    public Object getModelToMap(Node aNode, Object aParent) {
        SwingMLModel theContainer = (SwingMLModel) aParent;
        JSliderModel theModel = new JSliderModel();
        theModel.setParent(theContainer);
        theContainer.addChild(theModel);
        return theModel;
    }

    public void mapModel(Node aNode, Object aParent) {
        JSliderModel theModel = (JSliderModel) getModelToMap(aNode, aParent);
        this.mapModelAttributes(aNode, theModel, aParent);
        super.iterate(aNode, theModel);
    }

    public void mapModelAttributes(Node aNode, Object aModel, Object aParent) {
        JSliderModel theModel = (JSliderModel) aModel;
        super.mapCommonAttributes(theModel, aNode);
        Node theResultNode = super.getAttribute(aNode, Constants.VALUE);
        if (theResultNode != null) {
            try {
                int theValue = Integer.parseInt(theResultNode.getNodeValue());
                theModel.setValue(theValue);
            } catch (NumberFormatException e) {
            }
        }
        theResultNode = super.getAttribute(aNode, Constants.ENABLED);
        if (theResultNode != null) {
            if (theResultNode.getNodeValue().equals(Constants.FALSE)) {
                theModel.setEnabled(false);
            }
        }
        theResultNode = super.getAttribute(aNode, Constants.MINIMUM);
        if (theResultNode != null) {
            try {
                int theMinimum = Integer.parseInt(theResultNode.getNodeValue());
                theModel.setMinimum(theMinimum);
            } catch (NumberFormatException e) {
            }
        }
        theResultNode = super.getAttribute(aNode, Constants.MAXIMUM);
        if (theResultNode != null) {
            try {
                int theMaximum = Integer.parseInt(theResultNode.getNodeValue());
                theModel.setMaximum(theMaximum);
            } catch (NumberFormatException e) {
            }
        }
        theResultNode = super.getAttribute(aNode, Constants.TYPE);
        if (theResultNode != null) {
            if (theResultNode.getNodeValue().equalsIgnoreCase(Constants.HORIZONTAL)) {
                theModel.setType(JSlider.HORIZONTAL);
            }
            if (theResultNode.getNodeValue().equalsIgnoreCase(Constants.VERTICAL)) {
                theModel.setType(JSlider.VERTICAL);
            }
        }
    }

}