/* SwingML
 * Copyright (C) 2002 Robert Morris.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Robert Morris <robertj@morris.net>
 *     Ezequiel Cuellar <ecuellar@crosslogic.com> 
 *
 */

package org.swingml.xml.mapper;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.model.JSplitPaneModel;
import org.swingml.xml.Mapper;
import org.swingml.xml.MapperUtil;
import org.w3c.dom.Node;


public class JSplitPaneMapper extends MapperUtil implements Mapper {

    /**
     * @see org.swingml.xml.Mapper#getModelToMap(Node, Object)
     */
    public Object getModelToMap(Node aNode, Object aParent) {
        JSplitPaneModel theModel = new JSplitPaneModel();
        SwingMLModel theContainer = (SwingMLModel) aParent;
        theContainer.addChild(theModel);
        theModel.setParent(theContainer);
        return theModel;
    }

    /**
     * @see org.swingml.xml.Mapper#mapModel(Node, Object)
     */
    public void mapModel(Node aNode, Object aParent) {
        JSplitPaneModel theModel = (JSplitPaneModel) this.getModelToMap(aNode, aParent);
        this.mapModelAttributes(aNode, theModel, aParent);
        super.iterate(aNode, theModel);
    }

    /**
     * @see org.swingml.xml.Mapper#mapModelAttributes(Node, Object, Object)
     */
    public void mapModelAttributes(Node aNode, Object aModel, Object aParent) {
        JSplitPaneModel theModel = (JSplitPaneModel) aModel;
        super.mapCommonAttributes(theModel, aNode);
        Node theResultNode = super.getAttribute(aNode, Constants.TYPE);
        if (theResultNode != null) {
            theModel.setType(theResultNode.getNodeValue());
        }
        theResultNode = super.getAttribute(aNode, Constants.SIZE);
        if (theResultNode != null) {
            try {
                theModel.setSize(new Integer(theResultNode.getNodeValue()).intValue());
            } catch (NumberFormatException e) {
                System.out.println("Syntax Error: The SPLITTER [" + theModel.getName() + "] must only have a number in the SIZE attribute.");
                theModel.setSize(10);
            } catch (Exception e) {
                System.out.println(e);
            }
        }
        theResultNode = super.getAttribute(aNode, Constants.LOCATION);
        if (theResultNode != null) {
            Object theNewLocation = null;
            StringBuffer theValue = new StringBuffer(theResultNode.getNodeValue());
            if (theValue.length() == 0) {
                theNewLocation = new Double(25);
            } else {
                if (theValue.indexOf("%") < 0) {
                    try {
                        theNewLocation = new Integer(theValue.toString());
                    } catch (NumberFormatException e) {
                        System.out.println("Syntax Error: Only a numeric theValue can be placed in the LOCATION attribute of the Split Pane [" + theModel.getName() + "] tag.");
                        theNewLocation = new Double(25);
                    }
                } else {
                    int percentIdx = theValue.indexOf("%");

                    try {
                        theNewLocation = new Double(theValue.replace(percentIdx, percentIdx + "%".length(), "").toString());
                    } catch (NumberFormatException e) {
                        System.out.println("Syntax Error: Only a numeric theValue can be placed in the LOCATION attribute of the Split Pane [" + theModel.getName() + "] tag.");
                        theNewLocation = new Double(25);
                    }
                }
            }
            theModel.setLocation(theNewLocation);
        }
    }
} // public class JSplitPaneMapper extends MapperUtil implements Mapper