/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 * 	   Robert J. Morris <robertj@morris.net>
 *
 */

package org.swingml.xml.mapper;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.model.JTabbedPaneModel;
import org.swingml.xml.Mapper;
import org.swingml.xml.MapperUtil;
import org.w3c.dom.Node;


public class JTabbedPaneMapper extends MapperUtil implements Mapper {

    public Object getModelToMap(Node aNode, Object aParent) {
        JTabbedPaneModel theModel = new JTabbedPaneModel();
        SwingMLModel theContainer = (SwingMLModel) aParent;
        theContainer.addChild(theModel);
        theModel.setParent(theContainer);
        return theModel;
    }

    public void mapModel(Node aNode, Object aParent) {
        JTabbedPaneModel theModel = (JTabbedPaneModel) this.getModelToMap(aNode, aParent);
        this.mapModelAttributes(aNode, theModel, aParent);
        super.iterate(aNode, theModel);
    }

    public void mapModelAttributes(Node aNode, Object aModel, Object aParent) {
        JTabbedPaneModel theModel = (JTabbedPaneModel) aModel;
        super.mapCommonAttributes(theModel, aNode);

        Node theResultNode = super.getAttribute(aNode, Constants.CURRENT);
        if (theResultNode != null) {
            int theCurrent = 0;
            try {
                theCurrent = new Integer(theResultNode.getNodeValue()).intValue();
            } catch (Exception e) {
                theCurrent = 0;
                System.out.println("Syntax Error: A non-integer value was specified for the CURRENT attribute in the TABBEDPANE tag: [" + theModel.getName() + "].  Defaulted to 0.");
            }
            theModel.setCurrent(theCurrent);
        }
    }
}