/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.xml.mapper;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.model.JTableModel;
import org.swingml.xml.Mapper;
import org.swingml.xml.MapperUtil;
import org.w3c.dom.Node;


public class JTableMapper extends MapperUtil implements Mapper {
    
    public Object getModelToMap(Node aNode, Object aParent) {
        JTableModel theModel = new JTableModel();
        SwingMLModel theContainer = (SwingMLModel) aParent;
        theContainer.addChild(theModel);
        theModel.setParent(theContainer);
        return theModel;
    }

    public void mapModel(Node aNode, Object aParent) {
        JTableModel theModel = (JTableModel) this.getModelToMap(aNode, aParent);
        this.mapModelAttributes(aNode, theModel, aParent);
        super.iterate(aNode, theModel);
    }

    public void mapModelAttributes(Node aNode, Object aModel, Object aParent) {
        JTableModel theModel = (JTableModel) aModel;
        super.mapCommonAttributes(theModel, aNode);
        Node theResultNode = super.getAttribute(aNode, Constants.POST_STYLE);
        if (theResultNode != null) {
            theModel.setPostStyle(theResultNode.getNodeValue());
        } else {
            theModel.setPostStyle(Constants.POST_ALL);
        }
        theResultNode = super.getAttribute(aNode, Constants.POST_COLUMN);
        if (theResultNode != null) {
            int thePostColumn = 0;
            try {
                thePostColumn = Integer.parseInt(theResultNode.getNodeValue());
            } catch (Exception e) {
                thePostColumn = 0;
            }
            theModel.setPostColumn(thePostColumn);
        }
        theResultNode = super.getAttribute(aNode, Constants.MODE);
        if (theResultNode != null) {
            String theMode = theResultNode.getNodeValue();
            int theNewMode = javax.swing.ListSelectionModel.MULTIPLE_INTERVAL_SELECTION;
            if (theMode.equalsIgnoreCase(Constants.SINGLE)) {
                theNewMode = javax.swing.ListSelectionModel.SINGLE_SELECTION;
            } else {
                theNewMode = javax.swing.ListSelectionModel.MULTIPLE_INTERVAL_SELECTION;
            }
            theModel.setMode(theNewMode);
        }
    }
}