/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *     Farid Ibrahim <faridibrahim@lycos.com>
 * 
 */

package org.swingml.xml.mapper;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.component.ColorComponent;
import org.swingml.model.JTextFieldModel;
import org.swingml.xml.Mapper;
import org.swingml.xml.MapperUtil;
import org.w3c.dom.Node;


public class JTextFieldMapper extends MapperUtil implements Mapper {

    public Object getModelToMap(Node aNode, Object aParent) {
        JTextFieldModel theModel = new JTextFieldModel();
        SwingMLModel theContainer = (SwingMLModel) aParent;
        theContainer.addChild(theModel);
        theModel.setParent(theContainer);
        return theModel;
    }

    public void mapModel(Node aNode, Object aParent) {
        JTextFieldModel theModel = (JTextFieldModel) getModelToMap(aNode, aParent);
        this.mapModelAttributes(aNode, theModel, aParent);
        super.iterate(aNode, theModel);
    }

    public void mapModelAttributes(Node aNode, Object aModel, Object aParent) {
        JTextFieldModel theModel = (JTextFieldModel) aModel;
        super.mapCommonAttributes(theModel, aNode);
        Node theResultNode = super.getAttribute(aNode, Constants.COLS);
        if (theResultNode != null) {
            theModel.setCols(theResultNode.getNodeValue());
        }
        theResultNode = super.getAttribute(aNode, Constants.EDITABLE);
        if (theResultNode != null) {
            if (theResultNode.getNodeValue().equalsIgnoreCase(Constants.FALSE)) {
                theModel.setEditable(false);
            }
        }
        theResultNode = super.getAttribute(aNode, Constants.ENABLED);
        if (theResultNode != null) {
            theModel.setEnabled(theResultNode.getNodeValue().equalsIgnoreCase(Constants.TRUE));
        }
        theResultNode = super.getAttribute(aNode, Constants.FOREGROUND);
        if (theResultNode != null) {
            theModel.setForeground(ColorComponent.getColorByName(theResultNode.getNodeValue()));
        }
        theResultNode = super.getAttribute(aNode, Constants.BACKGROUND);
        if (theResultNode != null) {
            theModel.setBackground(ColorComponent.getColorByName(theResultNode.getNodeValue()));
        }
    }
}