/* SwingML
 * Copyright (C) 2002 Ezequiel Cuellar.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 *     Ezequiel Cuellar <ecuellar@crosslogic.com>
 *
 */

package org.swingml.xml.mapper;

//import java.util.*;
//import javax.swing.*;
import java.awt.Color;

import javax.swing.JComboBox;

import org.swingml.Constants;
import org.swingml.SwingMLModel;
import org.swingml.component.ColorComponent;
import org.swingml.model.TableDataModel;
import org.swingml.xml.Mapper;
import org.swingml.xml.MapperUtil;
import org.w3c.dom.Node;


public class TableDataMapper extends MapperUtil implements Mapper {

    public Object getModelToMap(Node aNode, Object aParent) {
        TableDataModel theModel = new TableDataModel();
        SwingMLModel theContainer = (SwingMLModel) aParent;
        int theColumnIndex = theContainer.getChildren().size();
        theContainer.addChild(theModel);
        theModel.setParent(theContainer);
        theModel.setColumn(theColumnIndex);
        return theModel;
    }

    public void mapModel(Node aNode, Object aParent) {
        TableDataModel theModel = (TableDataModel) this.getModelToMap(aNode, aParent);
        this.mapModelAttributes(aNode, theModel, aParent);
    }

    public void mapModelAttributes(Node aNode, Object aModel, Object aParent) {
        TableDataModel theModel = (TableDataModel) aModel;
        super.mapCommonAttributes(theModel, aNode);
        Node theResultNode = super.getAttribute(aNode, Constants.EDITABLE);
        if (theResultNode != null) {
            if (theResultNode.getNodeValue().equalsIgnoreCase(Constants.TRUE)) {
                theModel.setEditable(true);
            }
        }
        theResultNode = super.getAttribute(aNode, Constants.VALUE);
        if (theResultNode != null) {
            String theValue = theResultNode.getNodeValue();
            Object theType = theModel.getColumn().getType();
            if (theType instanceof Boolean) {
                theModel.setValue(new Boolean(theValue));
            }
            if (theType instanceof JComboBox) {
                theModel.setValue(theValue);
            }
            if (theType instanceof String) {
                theModel.setValue(theValue);
            }
            if (theType instanceof Color) {
                ColorComponent color = ColorComponent.getColorByName(theValue);
                theModel.setValue(color);
            }
        } else {
            theResultNode = super.getAttribute(aNode, Constants.TEXT);
            if (theResultNode != null) {
                theModel.setValue(theResultNode.getNodeValue());
            }
        }
    }
}